#include "gtk.h"
/* XPM */
static const char *const xpm_icon_0[] = {
/* columns rows colors chars-per-pixel */
"128 128 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoX+XoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXOXoXXXoXoXoXoXoXoXoXoXXXoXoXOXOX+X+X+X+X+X+XOXOXoXoXXXoXoXoXoXoXoXoXXXOX.X].+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X]..XOXXXoXoXoXoXoXoXoXoXoXoXoXOXOX+X+X+X+X+X+XOXOXoXoXXXoXoXoXoXoXoXoXXXoX+X+XoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoX6XyXtXtXtXtXtXtXtXyXpXuX=XC.&.W G C C G W *.C.=XuXpXyXtXtXtXtXtXtXyX2XOXL.A B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B A L.OX2XyXtXtXtXtXtXtXtXyXpXiX<XH.>.! H Z C F T +.b.#XtXaXyXtXtXtXtXtXtXyX6XoXOXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXXXyXcXzXzXzXzXzXxXmXpXQ.3.] N 7 %         % 8 N ] 4.Q.pXmXxXzXzXzXzXcX0X@XA.                                                                    A.@X0XcXzXzXzXzXzXxXmXfX].8.| A q &         # 4 b ( <.K.rXmXcXzXzXzXzXcXyXXXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXlXlXlXlXzXdX`.r.D #   7 F )  .+.+. .) D 7   # D e.`.fXzXlXlXlXxX9X@XA.+                                                                 + A.@X9XxXlXlXlXlXxXgX.Xs.T *   3 C / | +.@...` J w   o b 6.W.pXzXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXlXlXzXlXwXD.H & > b / w.^.:XeXkXkXeX:X~.q./ v : % H G.wXlXzXlXxX9X@XA.+                                                                 + A.@X9XxXlXlXlXzXyXT.! ; * z W 5.T.=XqXhXlXtX<X_.i.' M 2 @ n m.6XkXzXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXlXzXjX6Xx.e * r [ ~.jXxXzXzXlXlXlXlXzXzXxXjXQ.] r * r c.6XjXzXxX9X@XA.+                                                                 + A.@X9XxXlXlXkXqXA.k $ 0 Q L.dXzXzXzXlXlXlXlXzXzXxXlX{.#.i ; 3 i.,XhXzXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXlXlX6X0.5 : V G.aXjXlXlXlXlXlXlXlXlXlXlXlXlXjXaXF.C , 5 0.6XlXxX9X@XA.+                                                                 + A.@X9XxXlXlXrXf.t = c l.iXjXlXlXlXlXlXlXlXlXlXlXlXlXkXdX~.L 3 > -.;XzXxXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXzXwXx.5 : ' }.gXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgX}.` : 5 c.wXcX9X@XA.+                                                                 + A.@X9XxXzXuXH.t * T Q.fXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX&X@.2 > w.6XcXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXxXdXD.e , ' oXhXzXlXlXlXlXzXxXxXcXxXxXzXlXlXlXlXlXzXhXoX` > r G.gX0X@XA.+                                                                 + A.@X9XxXgX/.f - T (.fXxXlXlXlXlXlXlXxXcXcXxXlXlXlXlXlXlXzXjX;X@.3 6 g.sXyXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXmX_.G * Z |.hXxXlXlXlXzXhX~.1.^ U ( 5./.kXlXlXlXlXlXxXhX}.V * J ].tX+XA.+                                                                 + A.@X9XmX%XQ = z W.dXxXlXlXlXlXlXxXtXh.Y Q i.hXlXlXlXlXlXlXzXkX&XY = m P.aXXXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXyXaXr.% r F.gXzXlXlXlXxXuXD.F ,       1 L D.dXzXlXlXlXlXzXgXF.r & t.,X@XA.+                                                                 + A.@X0XfXN.> 1 c.iXcXlXlXlXlXlXzX0Xt.u   O ~ fXlXlXlXlXlXlXlXlXzXQ.x @ &.<XoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXXXpX!.D : [ aXlXlXlXlXlXzX$XM   > F ' D < X C >XkXlXlXlXlXlXlXaX[ : G V.&XA.+                                                                 + A.@XrX.XQ ; I 9XzXlXlXlXlXlXjX1Xq.8 . O * _ fXlXlXlXlXlXlXlXlXlXkX>.1 v z.OXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXuX3.@ v !.jXlXlXlXlXzXfXR.> ; [ ].rX{.]   ; U.aXzXlXlXlXlXlXjXQ.v % o.$XA.+                                                                 + A.@XeXx.* y J.dXzXlXlXlXlXzXaXm.5 7 c 9 & _ fXlXlXlXlXlXlXlXlXlXzX{.L # E .XoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoX-X'   / jXlXlXlXlXlXzXpX/.] ] }.fXxXxXA.  - x.tXxXlXlXlXlXlXlXhX^   I (.S.+                                                                 + A.#X-X2.  B uXlXlXlXlXlXlXzXpXd.b r.d.n $ _ fXlXlXlXlXlXlXlXlXlXlXxX:.. v U.XXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXOXV.N 7 w.xXlXlXlXlXlXlXlXjXfXfXjXkXjX9Xt.  < L.pXzXlXlXlXlXlXlXxX0.7 j k.S.+                                                                 + A.%XH.U 1 &.fXlXlXlXlXlXlXlXlXgX*XuXJ.c $ _ fXlXlXlXlXlXlXlXlXlXlXbXc.y t q..XoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXOX&.7 F ^.zXlXlXlXlXlXlXlXlXlXlXlXqXOX9.r + b 2XlXlXlXlXlXlXlXlXzX!.D 2 @.D.+                                                                 + A.*X8.r z K.jXlXlXlXlXlXlXlXlXlXhXcXJ.c $ _ fXlXlXlXlXlXlXlXlXlXlXcX|.~ , ! |.oXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XW % ) >XzXlXlXlXlXlXlXlXlXlXlXxX3.s < * A !.dXlXlXlXlXlXlXlXlXzX;X( # Q D.+                                                                 + A.=X+.& D #XkXlXlXlXlXlXlXlXlXlXlXvXJ.c $ _ fXlXlXlXlXlXlXlXlXlXlXxX4X=.$ M }.oXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XF    .rXlXlXlXlXlXlXlXlXlXlXlXxX)     o V .XhXzXlXlXlXlXlXlXlXlXeX .  K D.+                                                                 + A.=X'   L 7XkXlXlXlXlXlXlXlXlXlXlXvXJ.c $ _ fXlXlXlXlXlXlXlXlXlXlXzXiX7.. g }.oXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XC   +.kXlXlXlXlXlXlXlXlXlXlXlXzXW.w.E 2 < { 3XkXlXlXlXlXlXlXlXlXkX+.  F D.+                                                                 + A.-X(   I sXlXlXlXlXlXlXlXlXlXlXlXvXJ.c $ _ fXlXlXlXlXlXlXlXlXlXlXlXzXy.  p }.oXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XC   +.kXlXlXlXlXlXlXlXlXlXlXlXlXvXhX X..X : C.uXzXlXlXlXlXlXlXlXjX+.  F D.+                                                                 + A.-X(   P sXlXlXlXlXlXlXlXlXlXlXlXvXJ.c $ _ fXlXlXlXlXlXlXlXlXlXlXlXzXy.  p }.oXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XF    .eXlXlXlXlXlXlXlXlXlXlXlXlXlXzXnX~.9 % | 4XcXlXlXlXlXlXlXlXwX .  K D.+                                                                 + A.=X'   K 6XkXlXlXlXlXlXlXlXlXlXlXvXJ.c $ _ fXlXlXlXlXlXlXlXlXlXlXzXuX7.. g }.oXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XW % ) :XzXlXlXlXlXlXzXaX=X`.|.aXxXlXnX|.m $ U <XcXlXlXlXlXlXlXzX-X( # Q D.+                                                                 + A.=X+.* D @XkXlXlXlXlXlXlXlXlXlXlXvXJ.c $ _ fXlXlXlXlXlXlXlXlXlXlXxX3X*.$ M }.oXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXOX*.8 F ^.zXlXlXlXlXlXvX;Xo.* w {.hXhXkXY.0 % ] 3XcXlXlXlXlXlXlXzXQ.S 2 #.D.+                                                                 + A.*X9.t z K.jXlXlXlXlXlXlXlXlXlXlXvXJ.c $ _ fXlXlXlXlXlXlXlXlXlXlXcX}.! , ! |.oXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXOXC.N 7 q.xXlXlXlXlXlXxXqXs.@ + _ T.-XK.R . : k.rXxXlXlXlXlXlXlXxX8.6 k l.S.+                                                                 + A.%XK.Y 1 %.fXlXlXlXlXlXlXlXlXlXlXvXJ.c $ _ fXlXlXlXlXlXlXlXlXlXlXbXx.r t e..XoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoX-X]   / jXlXlXlXlXlXlXlXOXB O = q p 0 % @ G >XkXlXlXlXlXlXlXlXhX^   I (.S.+                                                                 + A.#X-X2.  B uXlXlXlXlXlXlXlXlXlXlXvXJ.c $ _ fXlXlXlXlXlXlXlXlXlXlXxX:.  b Y.XXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXuX4.# v Q.jXlXlXlXlXlXzXsX(.X.r     . u #.[.gXzXlXlXlXlXlXlXjXW.c & o.$XA.+                                                                 + A.@XeXc.= y G.dXzXlXlXlXlXlXlXlXlXvXG.h . ~ fXlXlXlXlXlXlXlXlXlXzX[.K # E .XoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXXXpX!.F : ] pXlXlXlXlXlXlXzXkX%XH.k.d.l.K.=XzXlXlXlXlXlXlXlXlXpX` : G C.&XA.+                                                                 + A.@XrXXX! - P 8XzXlXlXlXlXlXlXlXlXxX:XA.g.E.jXlXlXlXlXlXlXlXlXlXjX;.< v x.OXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXyXaXt.% r D.gXzXlXlXlXlXlXlXcXnXMXMXMXnXcXlXlXlXlXlXlXlXzXfXA.e * y.,X@XA.+                                                                 + A.@X0XfXB., 1 x.uXcXlXlXlXlXlXlXlXlXcXmXMXbXlXlXlXlXlXlXlXlXlXlXR.l @ &.<XoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXmX`.H * V }.hXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXhX[.N & K [.tX+XA.+                                                                 + A.@X9XnX%X~ = k E.dXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXkX%XI * M I.aXXXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXxXfXG.r > ` oXhXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXhXXX) > t H.gX0X@XA.+                                                                 + A.@X9XxXgX).g - Y /.fXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXjX;XO.3 7 h.dXyXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXzXwXc.5 : _ }.gXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXfX{.) ; 5 b.eXcX9X@XA.+                                                                 + A.@X9XxXzXuXH.t * U W.dXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgX%XO.2 > r.7XcXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXlXlX6X0.5 > B D.pXjXlXlXlXlXlXlXlXlXlXlXlXlXjXpXS.B , 5 q.6XlXxX9X@XA.+                                                                 + A.@X9XxXlXlXrXf.t - x j.yXjXlXlXlXlXlXlXlXlXlXlXlXlXkXsXQ.H 2 > :.;XzXxXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXlXzXjX6Xc.r & e ' Q.hXxXzXzXlXlXlXlXzXzXxXhXW.' e * t b.6XjXzXxX9X@XA.+                                                                 + A.@X9XxXlXlXkXqXS.l $ 9 E H.sXzXzXzXlXlXlXlXzXzXxXlX[.@.u ; 4 a.,XhXzXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXlXlXzXlXwXG.J & : v ~ 9.!.;XeXkXkXeX;X!.9.~ c ; & K G.eXlXzXlXxX9X@XA.+                                                                 + A.@X9XxXlXlXlXzXuXR.^ : & l R 3.Y.*XqXhXlXtX>X).y._ m 1 @ M m.7XkXzXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXXXyXcXxXxXxXxXcXgX].y.G %   7 D (  .+.+. .( S 7   % G y.].gXcXxXxXxXcX0X@XZ.                                                                    Z.@X0XcXxXxXxXxXcXkXOXf.E ;   2 V ^ | +.@..._ H w . + M 9.~.sXcXxXxXxXcXyXXXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoX2X0X9X9X9X9X9X0XtX,XC.o.I k 2 #         # 2 k U o.C.<XtX0X9X9X9X9X0X,XoXU._ / / / / / / / / / / / / / / / / / / / / / / / / / / / / / / / / _ U.oX,X0X9X9X9X9X9X0XtX4XL.$.R x 5 $         + , f K | x.-XtXqX0X9X9X9X0X2XOXOXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XXX.X.X.X.X.X.X.X.XXX+XOX!.h.+.W J D D J W +.h.~.OX+XXX.X.X.X.X.X.X.XoXXX{.$X$X$X$X$X$X$X$X$X$X$X$X%X*X=X=X-X-X-X=X=X*X%X$X$X$X$X$X$X$X$X$X$X$X{.XXoX.X.X.X.X.X.X.X.X.XOX+X(.l.#.R F V B S I } i.R.oX+XXX.X.X.X.X.X.X.XXX+X+XoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXOX%X*X*X*X*X*X*X*X*X*X=X=X@X'.R.K.G.F.F.G.K.R.'.@X=X=X*X*X*X*X*X*X*X*X$XOX@X*X*X*X*X*X*X*X*X*X*X-X&X.X^.P.G.D.A.S.F.L.!.|.%X=X=X*X*X*X*X*X*X*X*X@XOX$X*X*X*X*X*X*X*X*X*X*X*X*X=X=X-X-X-X-X-X-X-X=X*X*X*X*X*X*X*X*X*X*X*X%X+XOXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXrXlXkXkXkXkXkXkXkXgXuX3X).9.D w : # # : w D 9.).3XuXgXkXkXkXkXkXkXlX9X.X*XjXkXkXkXkXkXkXkXkXdXwX=XS...k 4 = @ & 2 f ` n.$X0XsXjXkXkXkXkXkXkXjX*X.X9XlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXrXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXlXlXlXlXlXkXjX:Xq.j 6 1 2 1 > * * > 1 2 1 6 j q.;XjXkXlXlXlXlXxX9X.X*XkXlXlXlXlXlXlXkXpX/.! r 3 1 2 < ; % - < 2 1 2 w K I.rXkXlXlXlXlXlXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXlXlXlXlXlX9Xe.V 8 $ = V 5.N.T.].].T.N.4.B = $ 7 B e.0XlXlXlXlXxX9X.X*XkXlXlXlXlXzXfX|.' h , O 0 ( d.G.~.}./.K.j.} y O : p W !.dXzXlXlXlXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXlXlXzXkX#X} w o y >.I.|.4XyXfXzXzXfXyX3X|.I.:.t o w | $XkXzXlXxX9X.X*XkXlXlXlXcXuXS.B > + L j.^.%X0XpXhXxXjXaXwX=X).n.Q $ = x l.wXcXlXlXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXlXxXdX(.( - 2 ` D.1XvXbXcXxXzXlXlXzXxXcXbXvX<XS.` 2 ; ) (.dXxXzX9X.X*XkXlXlXcX6Xj.x + g 0._.iXnXvXxXzXzXlXzXzXxXvXnXfX{.p.b $ s w.>XxXlXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXzXhX XR $ a <.%XvXcXlXlXlXlXlXlXlXlXlXlXlXlXcXvX$X<.s $ R  XhXcX9X.X*XkXlXzXuXj.a & H m.pXvXzXlXlXlXlXlXlXlXlXlXlXlXzXvXgXH.W > 9 9.wXlXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXxXlX%Xo.& p i.9XbXlXlXlXlXlXlXlXxXvXbXvXxXlXlXlXlXbX9Xu.p & O.&XxX0X.X*XkXlXfXS.c & I R.xXzXlXlXlXlXlXxXvXbXvXzXlXlXlXlXlXzXbX'._ : u x.pXjX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXxXcXvXbXvXvXxXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXvX7X9.$ w y.wXxXlXlXlXlXlXlXlXzX9X#XoX$XrXkXlXlXlXlXxXwXt.q $ q.0XwX.X*XkXkX|.B @ J R.xXlXlXlXlXlXlXkXtX$XOX*XiXzXlXlXlXlXlXlXvX].^ % s /.dX=X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXtX,X#XOX@X;XwXkXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXbXZ.r 2 | qXzXlXlXlXlXlXlXlXlXlXe.3 X t G.sXzXlXlXlXlXzXqX} 1 y D.eX.X*XkXpX_ > g m.xXlXlXlXlXlXlXlX0Xn.8 % j '.bXlXlXlXlXlXlXlXcXY.b : P 6X=X.X9XxXlXlXlXlXlXlXlXlXlXlXkXqXx.J 4 $ < B u.5XjXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXuX3X&.O x :XjXlXlXlXlXlXlXlXlXzXoXI     9 D.sXzXlXlXlXlXlXjX:Xc + *. XoX*XdX(.g O 9.iXzXlXlXlXlXlXzX8Xs.4 o . a `.nXlXlXlXlXlXlXlXzXdXn.* 0 J.XXXX9XxXlXlXlXlXlXlXlXlXlXzXtX,.9 @ + + + @ 1 o.4XxXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXaXz.r r r.fXlXlXlXlXlXlXlXlXlXxX6.4     9 D.sXzXlXlXlXlXlXlXfXe.r y 0.@X-XwX! , K ).vXlXlXlXlXlXxX3X7.4 o 1 o a `.nXlXlXlXlXlXlXlXlXcX#X^ , G T.OX9XxXlXlXlXlXlXlXlXlXzXgX}.e   a 6.I.i.l X 1 T.fXzXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXqX&.  D <XkXlXlXlXlXlXlXlXlXkX%XS o o   9 D.sXzXlXlXlXlXlXlXkX,XD   _ }.&X=Xr O j.iXxXlXlXlXlXlXvXQ.B 5 o.I $ a `.nXlXlXlXlXlXlXlXlXzXsXH.- < m..X0XxXlXlXlXlXlXlXlXlXxXtXz.@   9.6XgX0Xv.+ X r.8XxXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoX`.T # +.xXlXlXlXlXlXlXlXlXlXjX7.3 i d   9 D.sXzXlXlXlXlXlXlXlXxXO.$ Z F..XA.2 0 ^.nXlXlXlXlXlXlXxX>Xx.g.{...& a `.nXlXlXlXlXlXlXlXlXlXvX&Xs * <./.qXxXlXlXlXlXlXlXlXlXzXsX.Xj.a.:XcXzXnX+X- O -.1XcXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXOXi.f g n.xXlXlXlXlXlXlXlXlXhX-Xn   O.X.  9 D.sXzXlXlXlXlXlXlXlXxXv.f t 7./. .1 ( %XvXlXlXlXlXlXlXlXcXfXaX7X .& a `.nXlXlXlXlXlXlXlXlXlXcX5Xo.< J F.eXxXlXlXlXlXlXlXlXlXlXzXvXMXMXcXlXlXlX'.= O 5.5XcXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+X[ , R XXzXlXlXlXlXlXlXlXzXpXr.1 7 Z.i.  9 D.sXzXlXlXlXlXlXlXlXzX.XY - ' U.k 2 d.0XxXlXlXlXlXlXlXlXlXzXvX4X .& a `.nXlXlXlXlXlXlXlXlXlXzXyXN.8 w c.rXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX8Xq.O % C.iXzXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XP o [ 6XlXlXlXlXlXlXlXlXkX:Xl O O.;Xu.  9 D.sXzXlXlXlXlXlXlXlXlX4X] X U J.4 < H.aXzXlXlXlXlXlXlXlXlXlXcX4X .& a `.nXlXlXlXlXlXlXlXlXlXzXdX/.q * g.tXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXdXF.u + m *XcXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XS   o.aXlXlXlXlXlXlXlXxXeXf.: < L.xXr.  9 D.sXzXlXlXlXlXlXlXlXlXpXX.  G G.* ; ^.jXzXlXlXlXlXlXlXlXlXlXcX4X .& a `.nXlXlXlXlXlXlXlXlXlXlXjX@X9 o s.tXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXR.Z . 9 G.iXzXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XC   @.xXlXlXlXlXlXlXlXcX%Xz #  .-XvXr.  9 D.sXzXlXlXlXlXlXlXlXlXxX@.  D F.# % }.xXlXlXlXlXlXlXlXlXlXlXcX4X .& a `.nXlXlXlXlXlXlXlXlXlXlXzX1X6   a.tXxXlXlXlXlXlXlXlXlXlXlXlXlXlXxX).Y . 6 u.eXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XA   o.sXlXlXlXlXlXlXxXwXh.& ; D.8XtX5.  7 n.tXlXlXlXlXlXlXlXlXlXaXo.  G F.& - /.jXzXlXlXlXlXlXlXlXlXlXcX4X .& a `.nXlXlXlXlXlXlXlXlXlXlXjX$X9 X s.tXxXlXlXlXlXlXlXlXlXlXlXlXlXzXOX/ O 1 *.9XkXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XK X { 7XlXlXlXlXlXlXvX;XX.o + b F F y   @ b H.uXzXlXlXlXlXlXlXlX6X[ . P H.2 < K.aXzXlXlXlXlXlXlXlXlXlXcX4X .& a `.nXlXlXlXlXlXlXlXlXlXzXdX).q & f.tXxXlXlXlXlXlXlXlXlXlXlXlXlX,X} * * } :XzXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+X` : W @XzXlXlXlXlXlXvX$XQ             .   O y.wXxXlXlXlXlXlXlXzXOXE * ) I.f 2 k.wXxXlXlXlXlXlXlXlXlXlXcX4X .& a `.nXlXlXlXlXlXlXlXlXlXzXuXZ.9 8 x.rXxXlXlXlXlXlXlXlXlXlXlXkX7X*., + ( oXvXzXzXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXOXw.p z Z.xXlXlXlXlXlXxX8XN.%.#.#.$.$.M   * R ^.aXzXlXlXlXlXlXlXxXB.l w 3.~.` 1 | -XvXlXlXlXlXlXlXlXlXlXcX4X .& a `.nXlXlXlXlXlXlXlXlXlXcX7X*.1 A S.eXxXlXlXlXlXlXlXlXlXlXkX9Xq.3 X L Q.lXgXgXgXjXkXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoX~.P * &.xXlXlXlXlXlXlXzXbXmXmXmXMXNXi.  0 J.gXzXlXlXlXlXlXlXlXxX$.* B Z. Xn.2 y ).nXlXlXlXlXlXlXlXlXlXcX4X .& a `.nXlXlXlXlXlXlXlXlXlXvX*Xj = -.~.qXxXlXlXlXlXlXlXlXlXzXsXQ.8   $ _ b.b.v.v.n.XXpXzXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoX8X#.  J 9XkXlXlXlXlXlXlXlXlXlXlXlXxXe.  7 S.sXzXlXlXlXlXlXlXkX8XJ   / [.&X$Xw O n.fXzXlXlXlXlXlXlXlXlXcX4X} $ i _.nXlXlXlXlXlXlXlXlXzXgXR.- > c. X0XxXlXlXlXlXlXlXlXlXxXeXs.*                 3.4XcXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXaXd.6 p h.gXlXlXlXlXlXlXlXlXlXlXlXxXg.= l P.dXzXlXlXlXlXlXlXfXf.i 9 3.@X=X0XK : Q {.cXlXlXlXlXlXlXlXlXcX6X=.w N }.bXlXlXlXlXlXlXlXlXcX*X} > m I.OX9XxXlXlXlXlXlXlXlXlXxXtXc.t 2 3 3 3 3 3 3 7 y.7XxXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXuX:XX.O B 5XjXlXlXlXlXlXlXlXlXlXlXlXiX6X0XsXkXlXlXlXlXlXlXjX4XN + X.`.oX=XsXT.p $ i.gXzXlXlXlXlXlXlXlXlXjXtX8X0XfXzXlXlXlXlXlXlXlXzXhXA.; 6 N.|.XX9XxXlXlXlXlXlXlXlXlXlXkXpX8X7X7X7X7X7X7X7X7XiXjXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXxXm.8 4 =.yXzXlXlXlXlXlXlXlXlXlXlXzXxXxXzXlXlXlXlXlXlXzXtX%.3 0 N.0X.X*XjXtXQ = v G.bXlXlXlXlXlXlXlXlXlXzXxXxXlXlXlXlXlXlXlXlXlXbX^.S = S 1X*X.X9XxXlXlXlXlXlXlXlXlXlXlXzXxXxXxXxXxXxXxXxXxXzXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXbX1X:.@ u z.uXcXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXuXk.y # >.3XeX.X*XkXkX!.c # W '.vXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXOX} * t K.sX=X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXxXlX.X~ % z v.rXbXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXrXc.l % ^ XXzX0X.X*XkXlXdXl.a : ) ].cXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXbXOX+.3 0 r.uXjX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXzXfX).Z # x p.<XvXcXlXlXlXlXlXlXlXlXlXlXlXlXcXcX,Xi.z # A _.fXcX9X.X*XkXlXzXwXw.0 ; ~ U.sXcXzXlXlXlXlXlXlXlXlXlXlXlXzXcXhX/.| 3 2 -.7XlXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXlXxXpXL.G = 8 *.).8XxXcXxXzXzXlXlXzXzXxXcXxX8X(.*.8 - H I.aXxXxX9X.X*XkXlXlXcX>X9.u % b b.#XsXvXcXzXzXlXlXlXzXzXcXvXgX*XA.S = 0 -.%XxXlXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXlXlXzXhX}.U 4 + h t..X,XwXaXgXlXlXgXaXwX,X.Xr.g + 4 Y  XhXzXlXxX9X.X*XkXlXlXlXxXwXx.s : % ~ H.&X5XyXdXjXzXjXdXuX7X*XR.} ; = t e.7XxXlXlXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXtXzXlXlXlXlXjX1X,.d 1 ; 3 K p.U. X:X:X XU.p.K 3 ; < s ,.1XjXlXlXlXxX9X.X*XkXlXlXlXlXlXpX/.I 0 , = a X.N./.@X1X%X_.Z.*.k - > 5 A J.yXlXlXlXlXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXrXlXkXkXkXkXkXhXuX.X;.w * : 5 q 0 7 7 0 q 5 : * w :..XuXhXkXkXkXkXlX9X.X*XjXkXkXkXkXkXjXdX6XK.G < * < 8 q 9 6 8 q 9 2 = > m V.2XsXjXkXkXkXkXjX*X.X9XlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXrXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXOX%X*X*X*X*X*X*X*X-X#X).D.i.' g < @     @ < g ] p.D.).#X-X*X*X*X*X*X*X$XOX@X*X*X*X*X*X*X*X=X=XXXT.m.1.J w * X   . & 8 A ;.v.I. X*X=X*X*X*X*X*X*X@XOX$X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X%X+XOXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX[.OX$X$X$X$X$X$X$X$X%X*X*XoX!.S.n.z.k.k.z.n.S.~.oX*X*X%X$X$X$X$X$X$X$XXX}.OX.X.X.X.X.X.X.X.X.XXXOXXX).L.N.c.l.j.l.x.M.H./..XOXXX.X.X.X.X.X.X.X.XOX+XoX.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.XXX+X+XoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX X1.! / / / / / / / / / / ( ) ` ' ' ] ] ' ' ` ) ( / / / / / / / / / Q r.XX$X9X9X9X9X9X9X9X9X0XwXyX8X|.n.2.+.} ] } o.,.l.`.6XtXwX0X9X9X9X9X9X9X9X$XoX,X0X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X0X2XOXOXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX@Xn                                                                   Q $X*XlXxXxXxXxXxXxXvXbX9XI.p.o.M 3 O       o < x { y.F.4XcXbXxXxXxXxXxXlX*X.X0XcXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXcXyXXXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X*XkXlXlXlXlXzXlXrX(.w.d X @ e N H L I P J V u % . e 2.E.9XlXzXlXlXlXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X*XkXlXlXlXzXjX2Xz.h & 7 f R u.).:XwXhXtX,X].h.^ j 9 $ y y.:XhXzXlXlXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X*XkXlXlXlXjX-X1.: > e <.$XdXhXjXkXkXlXkXkXjXhXfX,X0.a > = ..+XgXlXlXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X*XkXlXlXzX X] ; 3 W XXtXhXlXlXlXlXlXlXlXlXlXlXlXjXyX*X} 8 - Y ^.lXlXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X*XkXlXzX>Xo.= 0 1.:XhXzXlXlXlXlXlXlXlXlXlXlXlXlXlXzXjX4Xt.a % W $XkXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X*XkXlXrX-.2 w 3.2XxXzXlXzXbXmXmXmXmXmXmXmXmXvXlXlXlXlXcX9Xp.s > ] 8XhX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXxXbXmXmXmXbXcXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X*XkXkXl.y : #.,XvXlXlXlXeXn.O.#.#.#.#.#.#.$.P.vXlXlXlXlXvX7X7.2 6 t.pX=X.X9XxXlXlXlXlXlXlXlXlXlXlXlXxX@Xx.<.%.>.g.}.kXzXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X*XhX4XD + T {.nXlXlXlXzX<XY                 $.mXlXlXlXlXlXnX&X} $ l #X%X.X9XxXlXlXlXlXlXlXlXlXlXzXgX/.} w       6 ! U.pXxXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X=XiXk.q 6 M.cXlXlXlXlXzX1X!   : n S S S S D c.bXlXlXlXlXlXlXcX!.t 2 q.'.oX9XxXlXlXlXlXlXlXlXlXlXkX3XU @ % f A l - X V @XlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X=X5Xc & @.=XcXlXlXlXlXzX1X!   b {.9X0X0X0X0XpXzXlXlXlXlXlXlXcX3X4.: i G.OX0XxXlXlXlXlXlXlXlXlXzXaXY.-   L I.6X/./ o O N.uXxXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / %X#X}.7 $ H.xXlXlXlXlXlXzX1X!   N -XhXjXkXlXkXlXlXlXlXlXlXlXlXlXzX{.< = f.{.0XxXlXlXlXlXlXlXlXlXxXrXx.t 1 G.kXlXkX).$ O 2.3XcXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / &X].y.2 c [.bXlXlXlXlXlXzX1X!   M @XqXqXaXgXkXlXlXlXlXlXlXlXlXlXcX:XS ; | T.wXxXlXlXlXlXlXlXlXlXlXkXpX8X7XsXlXlXvXOX> O ;.1XcXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / *XR.L 2 >.1XcXlXlXlXlXlXzX1X!   ; l f f B 4.%XcXlXlXlXlXlXlXlXlXxXqXw.4 z B.eXxXlXlXlXlXlXlXlXlXlXlXzXxXxXzXlXzXdXI.# O u.9XxXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / =XJ.t 1 m.tXxXlXlXlXlXlXzX1X!             2  . XcXlXlXlXlXlXlXlXzXpXL.0 2 k.rXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbX%X~ O < ~.hXzXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / =XF.> > Y.fXzXlXlXlXlXlXzX<XR   $ Z 7.9.M @ - 7.fXlXlXlXlXlXlXlXzXgX{.0 # d.tXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbX2X3.; # #.6XcXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / -XS.$ * '.lXlXlXlXlXlXlXlX9Xe.D | I.dXhXJ.f   U *XzXlXlXlXlXlXlXlXkX-X7   a.tXxXlXlXlXlXlXlXlXlXlXlXlXlXlXcX9Xu.9 O J oXgXzXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / -XS.# & [.xXlXlXlXlXlXlXlXfX1XOX>XgXlXlXjXW   v L.zXlXlXlXlXlXlXlXlX,X6   a.tXxXlXlXlXlXlXlXlXlXlXlXlXlXzXuXl.a   n E.gXzXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / -XD.- : E.gXzXlXlXlXlXlXlXzXxXcXxXlXlXlXcX| X g B.zXlXlXlXlXlXlXzXhX.X0 + d.tXxXlXlXlXlXlXlXlXlXlXlXlXlXsXS.z   j n.jXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / =XH.9 1 C.uXzXlXlXlXlXlXlXgXtX9XtXkXlXlXzX]   j A.zXlXlXlXlXlXlXzXaXR.q > h.tXxXlXlXlXlXlXlXlXlXlXlXlXfX!.b   u p.gXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / =XU.B 2 w.6XcXlXlXlXlXlXzX+X@.d @.tXjXjXwXH   C ^.zXlXlXlXlXlXlXxXrXh.6 a n.rXxXlXlXlXlXlXlXlXlXlXlXfX.XN o 5 0.uXkXkXkXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / &X_.1.1 G XXbXlXlXlXlXlXlX8X`   w 6.*X=X1.7   ` 9XlXlXlXlXlXlXlXcX<XR > ^ P.wXxXlXlXlXlXlXlXlXlXlXhX&XH % $ %.#XqX0X0X0XpXjXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / %XOXQ.4 > R.bXlXlXlXlXlXlXkXz.r   6 N N 4   d B.lXlXlXlXlXlXlXlXcX+X8 * e.`.qXxXlXlXlXlXlXlXlXlXzXuXB.,   o p D D S S G M.qXxXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X*X1Xs @ 7.6XcXlXlXlXlXlXxX3Xh.B *     % C v.8XxXlXlXlXlXlXlXxXwXh.- 8 Z.oX0XxXlXlXlXlXlXlXlXlXxXwXu.O                 >.3XcXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X=XyX:.4 h L.vXlXlXlXlXlXlXvXeXR.w.*.*.0.W.rXvXlXlXlXlXlXlXlXvX[.m <  .^.OX9XxXlXlXlXlXlXlXlXlXzXaX).:.#.#.#.#.#.#.#.&.T.tXxXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X*XgX%Xb X O.<XcXlXlXlXlXlXlXzXvXnXmXmXnXvXzXlXlXlXlXlXlXlXcX7X6.+ i _.@XXX9XxXlXlXlXlXlXlXlXlXlXlXcXmXmXmXmXmXmXmXmXmXvXzXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X*XkXhX,.7 8 q.iXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXsXx.r 2 o.rX=X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X*XkXkX3XQ % z c.aXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXF.V & Z =XgX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X*XkXlXkX}.U @ l l.aXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXgXZ.B # M ^.gXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X*XkXlXlXgXI.S # s -.6XlXzXlXlXlXlXlXlXlXlXlXlXlXlXlXrX8.l % x V.sXlXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X*XkXlXlXxXuX!.^ + 6 P x.8XnXvXxXzXzXlXzXzXxXvXbXtXC.Q q + J L.rXzXlXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX+XB                                                                   / $X*XkXlXlXlXcXfX}.#.9 . f ` q.K.*X0XfXvXgXwX-XT.t.| x X 2 [ ~.sXcXlXlXkX*X.X9XxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX@Xm                                                                   ! $X*XlXzXzXzXzXcXzX2Xd.( 9   * m  .1.q.i.w.3.o.Z >   3 R e.*XlXcXzXzXzXlX*X.X0XcXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXcXyXXXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX.Xo.m B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B n 1.OX%XrXtXtXtXtXtXtXuXuX}.=.F h 7 = +       O * 5 f S o.(.rXiXtXtXtXtXtXrX%XXX2XyXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXyX6XoXOXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoX]..X@X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X@X X{.+XoXoXoXoXoXoXoXoXoXoX+X].N.&.H z s u a l D O.v.`.OXoXoXXXoXoXoXoXoXoX+X+XOXXXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXXXoX+XXXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXOXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXOX+XOXoXoXoXoXoXoXoXoXoXoXoXoXXX X|.}.}.}.}.}.|. X.XoXoXoXoXoXoXoXoXoXoXoXOX+XOXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXOXXX'.XXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXXXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX"
};

/* XPM */
static const char *const xpm_icon_1[] = {
/* columns rows colors chars-per-pixel */
"96 96 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXOXOXOXOXOXOXOXOXOXXX X|.}.}.}.|. XoXOXOXOXOXOXOXOXOXoXOX.X{.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.{..XOXoXOXOXOXOXOXOXOXOXOXXX X|.}.}.}.|. XoXOXOXOXOXOXOXOXOXOXoXoXoXoXoX",
"oXoXoXoX+X.X}.|.}.}.}.|.}.].`..X-X2X4X5X4X2X=X X`.].}.|.}.}.|.}.XX}.*X7X4X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X4X7X*X}.XX}.|.}.}.}.|.}.].`..X-X2X4X5X4X1X=X X`.[.}.|.}.}.|.}..X+XoXoXoXoX",
"oXoXoXoX.X<XwX9X0X0X0X8X5XpXkX$Xd.@.[ ` { $.j.*XlXiX5X8X0X0X9XwX,X%X0.I / ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ / I 0.%X,XwX9X0X0X0X8X5XaXkX@Xa.@.[ ` { $.l.-XlXuX5X8X0X0X9XwX<XXXOXoXoXoX",
"oXoXoXOX}.wXMXcXvXvXxXMXDXR.` N =           : V [ /.GXmXxXvXcXMX8X2XK                                                     K 2X8XMXcXvXvXxXNXSXP._ M *           > Z { `.GXmXxXvXcXMXwX}.OXoXoXoX",
"oXoXoXOX|.9XcXjXkXkXmX%XY 4   +  .m.R.[.Y.b.] .   5 E ,XnXkXjXcX6X<X~   $ O O O O O O O O O O O O O O O O O O O O O O $   ~ <X6XcXjXkXkXmXOXP 2   $ o.M.R.[.U.v.)     7 ~ 3XnXkXjXcX9X|.OXoXoXoX",
"oXoXoXOX}.0XvXkXzXnXY.2   t U.qXsXvXMXCXMXcXaX0XF.7   7 /.mXkXvX6X<XW   O                                             O   W <X6XvXkXzXnXJ.,   a E.qXdXvXNXCXMXcXpX0XZ.3   0 '.mXkXvX0X}.OXoXoXoX",
"oXoXoXOX}.0XvXkXnXl.+ + 5.hXxXmXxXkXhXgXjXlXcXmXxXdX-.O & N.mXxX7X<XW   O                                             O   W <X6XvXkXbXf.o $ q.jXxXmXcXlXhXgXjXzXcXmXxXsX#.X - S.mXxX0X}.OXoXoXoX",
"oXoXoXOX}.0XxXmXY.+ > S.VXzXlXjXzXNXCXCXNXxXjXkXlXxXBXn.& = ^.VX4X<XW   O                                             O   W <X7XxXmXJ.X 2 K.VXlXlXkXkXkXVXZXMXkXlXkXlXxXNXl.@ > `.VX7X|.OXoXoXoX",
"oXoXoXOX|.8XMX$X1 # S.VXjXlXkXbXjX>X+X+X;XfXnXjXlXlXkXBXn.  q 4X0X>XQ   O                                             O   W <X5XMXOX; * K.VXjXlXlXkXlXbX%X}.,XcXkXlXlXlXlXBXl.  u 8XeX{.OXoXoXoX",
"oXoXoXOX}.5XFXU   5.VXjXlXkXlXsXw.<     * ;.eXcXkXlXlXkXMX-.  { aX-XW   O                                             O   W <X2XSXD   q.CXhXlXlXkXxXnXS.    T SXgXlXlXlXlXlXnX#.  @.hX`.OXoXoXoX",
"oXoXoXOX].pXE.4 t gXzXlXlXgXSXt.  + R ^ ;   *.CXgXlXlXkXcXiX6 r V.0XT   O                                             O   W :XyXP.< a zXkXlXlXlXkXhXv.  . X [ AXgXlXlXlXlXkXbXwX1 p J.$X.XoXoXoX",
"oXoXoXOX`.lX`   U.xXlXlXkXkXzXU   4.jXnXx.  v 0XxXjXlXlXlXxXC.  E pXU   O                                             O   W -XfXE   Q.xXlXlXlXhXNXE.  z I   ` AXgXlXlXlXlXlXlXxXb.  [ ,X|.oXoXoX",
"oXoXoXXX.X#XM + qXmXkXlXlXzXfX.XK.yXkXBX:X  b 1XvXjXlXlXjXBX1X. l &XQ   O                                             O   E 3X Xz & uXbXkXlXlXjXvX<Xq.>X2.  ` AXgXlXlXlXlXlXjXVX=X  V `.+XXXoXoX",
"oXoXoX X-Xd.=  .sXcXlXlXlXlXzXVXFXxXkX*XJ   ^ VXgXlXlXlXkXvXuX) o A.'   O                                             O   Y tXq.& @.fXxXlXlXlXlXjXNXmXNX&.  ` AXgXlXlXlXlXlXkXvXrXQ & l.;X XoXoX",
"oXoXoX|.2X#.  m.vXlXlXlXlXlXlXjXdXmXE 1   L 3XvXjXlXlXlXlXlXcXf.  u. .  O                                             O   U dX'   A.vXlXlXlXlXlXlXjXjXvX*.  ` AXgXlXlXlXlXlXlXlXxXy.  5.1X|.oXoX",
"oXoXoX}.4X[   E.NXkXlXlXlXlXlXlXjXBXs     V 9XxXjXlXlXlXlXkXNXD.  9.X.  O                                             O   I gXR   (.MXkXlXlXlXlXlXlXkXbX*.  ` AXgXlXlXlXlXlXlXjXBXM.  >.3X|.oXoX",
"oXoXoX}.5X`   [.CXjXlXlXlXlXlXkXjXlXgXOXS   R xXjXkXlXlXlXjXSXE.  8.X.  O                                             O   I gXU   OXVXkXlXlXlXlXlXlXkXbX*.  ` AXgXlXlXlXlXlXlXhXDXJ.  :.3X|.oXoX",
"oXoXoX}.4X[   Y.MXkXlXlXlXkXcXBXCXlXlXBX>Xo 4 ~.BXhXlXlXlXkXNXA.  0.X.  O                                             O   I gXE   ^.mXkXlXlXlXlXlXlXkXbX*.  ` AXgXlXlXlXlXlXlXkXNXm.  >.3X|.oXoX",
"oXoXoX|.2X$.  b.cXlXlXlXkXcXqX^.Y.jXxXbXiXg @ C.SXgXlXlXlXzXxXs.  i. .  O                                             O   U sX]   C.vXlXlXlXlXlXlXlXkXbX*.  ` AXgXlXlXlXlXlXlXzXzXr.  5.1X|.oXoX",
"oXoXoX X=Xj.: ] aXcXlXlXhXMX X<   L.VXVX/.X 4 ~.BXhXlXlXkXvXtXQ @ F.'   O                                             O   Y rXt.- ..dXxXlXlXlXlXlXlXkXbX*.  ` AXgXlXlXlXlXlXkXbXwXU - x.-X XoXoX",
"oXoXoXoX X*XC . 0XmXkXlXkXjXvX .  0 -.<.y   T hXkXkXlXlXjXBX,X  c -XW   O                                             O   E 2X+Xv @ yXnXkXlXlXlXlXlXkXbX:.  { AXgXlXlXlXlXlXjXCX&X  A ].OXXXoXoX",
"oXoXoXOX`.lX[   F.xXlXlXlXjXmX>X{ +       ~ &XMXhXlXlXlXlXzXb.  ! pXU   O                                             O   W -XgX!   P.xXlXlXlXlXlXlXkXnX}   I DXgXlXlXlXlXlXlXzXk.  } <X|.oXoXoX",
"oXoXoXOX[.iX(.6 7 dXxXlXlXzXhXNXpX`.K.K./.tXBXhXzXlXlXkXvXeX: u G.8XT   O                                             O   W :XrXQ.2 e jXlXlXlXlXlXlXlXxXoXC.{.bXkXlXlXlXlXkXbX8X* f Y.#X.XoXoXoX",
"oXoXoXOX}.5XGXW   =.BXkXlXlXzXhXxXZXGXGXAXcXhXzXlXlXlXlXnX .  o.sX-XW   O                                             O   W <X2XDXL   1.VXjXlXlXlXlXlXlXBXHXCXkXlXlXlXlXlXzXcX'   =.jX`.OXoXoXoX",
"oXoXoXOX|.8XmX,X7 o n.BXkXkXlXlXkXhXgXgXhXkXlXlXlXkXlXNXf.  u qX9X,XQ   O                                             O   W <X5XmX=X1 # C.VXkXkXlXlXlXlXjXgXjXlXlXlXlXkXzXMXu.  f rXwX{.OXoXoXoX",
"oXoXoXOX}.0XxXnX/.& & b.MXcXlXjXkXlXlXlXlXlXkXjXlXvXnXf.O , }.BX4X<XW   O                                             O   W <X7XxXnXE.+ - B.NXcXlXjXkXlXlXlXlXlXkXjXzXvXbXu.. 4 oXBX7X|.OXoXoXoX",
"oXoXoXOX}.0XvXkXmXN.=   *.yXxXBXvXlXkXjXkXzXvXBXzXeX..  , H.mXcX7X<XW   O                                             O   W <X6XvXkXnXc.% X ,.iXcXBXcXlXkXjXkXzXvXBXzXqX]   3 I.mXxX0X}.OXoXoXoX",
"oXoXoXOX|.9XcXjXkXmX^.q   4 C.<XyXcXNXSXNXxXtX,Xn.:   y }.mXjXcX6X<X!   # o o o o o o o o o o o o o o o o o o o o o o #   ! <X6XcXjXlXmXE.8   9 D.1XuXcXBXSXNXxXrX,Xx.*   a oXnXjXcX9X|.OXoXoXoX",
"oXoXoXOX}.wXMXcXvXxXVX4X} t     ) f.D.E.S.s.!     u o.0XBXcXcXMX8X2XK                                                     K 2X8XMXcXvXxXCX<X] w   X ` g.F.E.A.a.E     p @.rXBXcXcXMXwX}.OXoXoXoX",
"oXoXoXOX X1XtXwXeXeX0XyXkXG.( b @           $ M _ U.lXtX0XeXwXtX<X%X6.F E Y Y Y Y Y Y Y U L K J J J K L U Y Y Y Y Y Y E F 6.%X<XtXwXeXeX0XuXjXA.^ b %           ; V ' E.zXtXqXeXwXtX1X.XOXoXoXoX",
"oXoXoXXX+X|.`.'.'.'.'._./. X$X/.v.r.9.7.9.t.n.).$X|./._.'.'.'.`. X X$X2X<X<X<X<X<X<X:X-X3XtXdXgXgXgXsXrX2X-X:X<X<X<X<X<X2X$X X X`.'.'.'.'._./.OX-XQ.y.&.o...O.=.d.).;X.X/.`.'.'.'.`.|.#XOXoXoXoX",
"oXoXoXOX.X1XrXqXwXwXwX0X7XiXfX%Xc.1.*.#.*.3.n.*XgXuX7XqXwXwXqXrX2X X,X7X5X5X5X6X4X1XtXdX.Xe.{ ~ E ~ | p.@XfXrX1X4X6X5X5X7X,X X2XrXqXwXwXwXwXwX9X7XeXdXlXzXxXzXkXsXqX6X9XwXwXwXwXqXrX1X.XOXoXoXoX",
"oXoXoXOX}.wXMXcXvXvXxXMXSXU.^ v $           * m ) !.FXmXxXvXcXMXtX`.rXMXcXvXvXxXNXSXP.^ b *           ; M _ ^.FXmXxXvXcXMXrX`.tXMXcXvXvXvXvXvXvXvXcXzXlXkXkXkXlXzXcXvXvXvXvXvXvXcXMXwX}.OXoXoXoX",
"oXoXoXOX|.9XcXjXkXkXnX@XL 2   $ o.B.Q. XW.M.} o   3 U ;XnXkXjXcXwX'.qXcXjXkXkXmXOXK 1   % +.V.!. XE.M.[ X   4 T ,XnXkXjXcXqX'.wXcXjXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXjXcX9X|.OXoXoXoX",
"oXoXoXOX}.0XvXkXzXnXP.,   i R.rXdXvXMXVXMXcXsXeXJ.0   4 !.nXkXvXeX'.wXvXkXzXnXJ.>   a W.rXdXvXMXVXMXcXsXeXG.8   5 /.nXkXvXwX'.eXvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoXOX}.0XvXkXnXh.o # 8.kXxXnXxXlXkXhXhXkXxXnXxXhX>.@ # n.mXxXeX'.wXvXkXnXf.X % q.lXxXnXxXlXhXgXjXzXcXnXxXgX-.+ % N.mXxXwX'.eXvXkXlXlXlXlXlXlXlXlXkXjXjXjXjXkXlXlXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoXOX}.0XxXmXP.O < G.VXlXlXkXlXlXkXBXAXCXxXkXlXzXVXN.= & Q.CX0X'.wXxXmXJ.X 2 K.VXlXlXkXkXkXVXAXNXkXlXkXlXzXBXn.& - ^.CX9X'.eXvXkXlXlXlXlXlXlXlXjXxXBXZXZXBXxXjXlXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoXOX|.8XNX@X< $ G.VXjXlXlXlXlXlXcX%X`.XXaXzXkXlXkXVXM.. 9 2XuX_.0XNXOX: & K.VXhXlXlXkXkXbX@X'.;XcXkXlXlXlXkXBXn.  w 4XyX_.eXvXkXlXlXlXlXlXlXjXnXgX=X.X.X-XhXnXjXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoXOX}.5XDXP   8.VXjXlXlXlXlXlXlXyX,   = +XbXjXlXlXkXMX>.  [ jX/.7XSXH   q.VXhXlXlXkXzXmXS.    L SXgXlXlXlXlXkXmX-.   .jX/.eXvXkXlXlXlXlXlXkXcXwX,.-     > 3.tXxXkXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoXOX].pXT.3 u hXzXlXlXlXlXlXjXBX8.X   y %XvXjXlXlXkXcXpX8 e D..XiXI.1 a kXlXlXlXlXkXhXc.  . o ` ZXgXlXlXlXlXkXvXyX5 t G.OX0XvXkXlXlXlXlXlXgXCX>.  - ( ^ %   1.CXgXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoXOX`.lX_   T.xXlXlXlXlXlXlXkXeX9     q $XvXjXlXlXlXlXxXA.  / #XgX~   W.xXlXlXlXhXNX!.  x R   / ZXgXlXlXlXlXlXlXxXV.  ` -X8XvXkXlXlXlXlXjXcX2X8   g.nXvXp.  M qXxXjXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoXXX.X@XM # qXmXkXlXlXlXlXgXAX1.. D   w $XvXjXlXlXlXjXBX1XX c ^.#Xc % rXnXkXlXlXkXvX3Xt.,X5.  / ZXgXlXlXlXlXlXjXBX>X  M !.rXxXkXlXlXlXlXkXcXwXU.z.fXzXBX,X  j @XmXhXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX X-Xs.* X.sXcXlXlXlXlXkXzX7Xw X _.  w $XvXjXlXlXlXkXvXuX_ + v.z.# +.dXxXlXlXlXlXkXMXmXBX-.  / ZXgXlXlXlXlXlXkXvXyX/ & a.fXzXkXlXlXlXlXlXkXvXDXKXzXhXmX^.  m 4XvXjXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX|.2X@.  M.vXlXlXlXlXlXfXGX<.  O.8X  e $XvXjXlXlXlXlXlXcXf.  r.1.  V.vXlXlXlXlXlXlXjXjXbX;.  / ZXgXlXlXlXlXlXlXlXxXa.  ;.lXlXkXlXlXlXlXlXlXkXhXgXkXbXaXZ   o.AXgXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.4X[   E.NXkXlXlXlXjXvX<Xp   2X9X  e $XvXjXlXlXlXlXkXBXF.  9.&.  ~.MXkXlXlXlXlXlXlXjXnX;.  / ZXgXlXlXlXlXlXlXkXBXZ.  #.xXkXkXlXlXlXlXlXlXlXlXlXxXxXO.  s <XbXjXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X`   [.CXjXlXlXlXfXDX2.  >.CXrX  r -XnXjXlXlXlXlXjXSXE.  8.$.   XVXjXlXlXlXlXlXlXkXnX;.  / ZXgXlXlXlXlXlXlXhXSXU.  @.xXkXkXlXlXlXlXlXlXlXkXlXbX8.  1 ).MXhXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.4X[   Y.MXkXlXlXjXbX>Xc   B.OXJ.  3 H.gXkXkXlXlXlXkXMXA.  9.&.  E.MXkXlXlXlXlXlXlXkXnX;.  / ZXgXlXlXlXlXlXlXkXNXB.  #.xXkXkXlXlXlXlXlXlXlXjXmXx.  + V.VXhXlXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX|.1X$.  v.cXlXlXlXhXVX!.$         +   , #XnXhXlXlXlXzXxXa.  t.3.  M.cXlXlXlXlXlXlXlXkXnX;.  / ZXgXlXlXlXlXlXlXzXzXu.  :.lXlXkXlXlXlXlXlXlXjXBXK.X   y.NXfXjXlXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX X=Xk.: ' aXcXlXlXjXnX=X%.~ ] { !   @ @.9XxXkXlXlXkXvXrXE % m.m.* { sXcXlXlXlXlXlXlXkXnX;.  / ZXgXlXlXlXlXlXkXvXeXT ; g.dXzXkXlXlXlXlXlXjXbX~.>   e.JXNXCXNXzXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoXoX X=XZ   0XmXkXlXlXkXnXKXUXIXUXkX  f 7XMXhXlXlXlXjXBX,X  M ).-XM X eXnXkXlXlXlXlXlXkXnX<.  ` ZXgXlXlXlXlXlXjXVX-X  Z (.eXcXkXlXlXlXlXkXzXtXM   2 3.2.4.>.j.eXcXkXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoXOX`.lX{   S.xXlXlXlXlXjXdXsXsXkX;X  %  XvXjXlXlXlXlXzXc.  ` $XhX_   G.xXlXlXlXlXlXlXkXmXX.  J SXgXlXlXlXlXlXzXzXl.  [ -X8XvXkXlXlXlXlXhXnX+X2             & *XnXhXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoXOX[.uX`.7 5 sXxXlXlXlXlXlXlXlXxXsXA.E.yXzXkXlXlXkXvXwX- p Y.|.uX(.4 8 fXzXlXlXlXlXlXlXxX#XF.|.vXkXlXlXlXlXkXbX0X* s R.XX0XvXkXlXlXlXlXkXzXiX~.D.J.P.I.U.K._.pXzXkXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoXOX}.5XHX!   %.NXkXlXlXlXlXlXlXlXxXHXDXcXlXlXlXlXzXbX{   +.lX/.7XGXR   =.BXkXlXlXlXlXlXlXBXGXCXkXlXlXlXlXlXzXvX'   %.lX/.eXvXkXlXlXlXlXlXlXcXSXHXGXGXGXGXHXAXxXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoXOX|.8XmX1X9 X c.BXlXkXlXlXlXlXlXlXgXhXkXlXlXkXzXNXa.  p wXtX_.qXmX,X5 O n.BXkXkXlXlXlXlXjXgXjXlXlXlXlXkXzXMXu.  d rXrX_.eXvXkXlXlXlXlXlXlXlXhXgXhXhXhXhXgXhXlXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoXOX}.0XxXnX_.* $ x.mXvXlXjXkXlXlXlXlXlXkXjXlXbXbXa.X 1  XBXqX'.wXxXnX/.% & b.mXvXlXjXkXlXlXlXlXlXkXjXlXbXvXu.. 3 oXBX0X'.eXvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoXOX}.0XvXkXmXC.;   $.rXxXVXvXlXkXhXkXzXvXVXzXqX}   2 L.mXcXeX'.wXvXkXnXN.-   *.tXcXBXvXlXkXhXkXzXvXVXzX0X]   3 I.mXxXwX'.eXvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoXOX|.9XcXjXkXmX).r   2 N.:XtXxXBXSXNXxXeX;Xx.-   a  XmXjXcXwX'.qXcXjXkXmX^.w   4 V.:XyXxXBXSXNXzXeX-Xl.*   d oXmXjXcXqX'.wXcXjXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXjXcX9X|.OXoXoXoX",
"oXoXoXOX}.wXMXcXvXxXVX6Xo.u     ^ a.C.U.V.i.E     a #.wXBXxXcXMXtX`.rXMXcXvXxXCX4X..y     / a.Z.U.V.u.T     s %.rXBXxXcXMXrX`.tXMXcXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXcXMXwX}.OXoXoXoX",
"oXoXoXoXXX>X7X5X5X6X3X9XaXA.~ c O           # n ( J.dX8X3X6X5X7X<X X2XrXqXwXwX9XyXjXG.` m @           & C { E.lXrX0XwXqXrX2X}.3XrXqXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXqXrX1X.XOXoXoXoX",
"oXoXoXOX}.$X2X<X<X<X<X>X-X9XpX=XF.s.e.q.r.s.H.:XaX8X-X,X<X<X<X2X%X X X`.'.'.'.'._./. X$X/.m.i.e.q.e.p.N.`.%X}./._.'.'.'.`.}.$X}.`.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.'.`.|.#XOXoXoXoX",
"oXoXoX.X=X8.D E Y Y Y T Y P K T ( [ { } { [ ( Y K I Y T Y Y R F 4.%X<XtXwXeXeXeXqX9XpXgX#Xk.:.@.o.#.,.v.*XhXiX9XwXeXeXwXtX3X}.3XtXwXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXwXtX1X.XOXoXoXoX",
"oXoXoX{.7XU                                                     F 2X7XMXcXvXvXxXNXAXH.E l #           * v ~ Q.DXmXxXvXcXMXrX`.tXMXcXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXcXMXwX}.OXoXoXoX",
"oXoXoX}.4X/   # o o o o o o o o o o o o o o o o o o o o o o #   R <X5XcXjXkXkXmXXXF ,   = $.A./.OX~.V.| +   2 P ;XnXkXjXcXqX'.wXcXjXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXjXcX9X|.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   Y <X5XvXkXzXbXF.-   f ~.uXgXvXMXVXmXcXdXyXK.q   3 !.nXkXvXwX'.eXvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   Y <X5XvXkXnXa.  * r.xXxXvXlXjXhXgXhXjXzXnXxXjX,.# # n.mXxXwX'.eXvXkXlXlXlXlXlXlXlXlXkXjXjXjXjXkXlXlXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   Y <X6XxXmXF.. 4 P.CXkXlXBXSXAXAXAXAXSXMXjXzXlXVXN.= * Q.CX9X'.eXvXkXlXlXlXlXlXlXlXjXxXBXAXAXBXxXjXlXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   Y <X4XNX.X; = P.CXhXlXkX@X^.].[.[.[.`.>XbXkXlXjXVXM.  q 2XyX_.eXvXkXlXlXlXlXlXlXjXmXfX%X{.{.&XgXmXjXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   Y <X1XSXG   r.VXhXkXlXdXk             P UXsXlXlXkXMX>.  | hX/.eXvXkXlXlXlXlXlXjXcXqX;.=     ; ,.eXcXkXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   Y :XyXK.< d lXlXlXkXlXdXK   L O.X.O.' C.ZXgXlXlXkXvXuX7 r D.OX9XvXkXlXlXlXlXlXgXCX;.  ; ' _ &   ,.CXgXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   Y -XfX~   !.xXlXlXkXlXdXH   P.VXnXbXNXnXkXlXlXlXlXlXcXZ.  _ -X8XvXkXlXlXlXlXjXcX2X8   k.mXbXs.  m 0XcXjXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   U 3X|.c & rXnXkXlXkXlXdXH   !.DXBXSXzXgXzXlXlXlXlXjXBX>X. m Q.rXxXkXlXlXlXlXkXxXeXE.m.gXzXBX,X  j @XmXhXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   L tXw.& @.fXxXlXlXkXlXdXD   v N v / [.BXhXlXlXlXlXkXvXyX) % p.fXzXkXlXlXlXlXlXkXvXDXKXzXhXmX~.  m 5XvXjXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   K dX{   C.vXlXlXlXkXlXdXA           e ~.BXhXlXlXlXlXlXcXs.  ;.lXlXkXlXlXlXlXlXlXkXhXgXkXbXpXV   +.SXgXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   J gX!   ~.MXkXlXlXkXlXdXG   U -X>XS   R bXhXkXlXlXlXkXBXZ.  #.xXkXkXlXlXlXlXlXlXlXlXkXxXzX..  f 2XvXjXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   J gXW    XVXjXlXlXlXlXjXXXP.9XbXZXoX  d $XnXhXlXlXlXhXSXU.  @.xXkXkXlXlXlXlXlXlXlXkXlXbX5.  2 `.MXhXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   J gX~   E.MXkXlXlXlXlXxXAXHXxXhXMX,XX 9 _.BXhXlXlXlXkXMXB.  $.xXkXkXlXlXlXlXlXlXlXjXmXk.  @ Z.VXhXlXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   K sX .  m.cXlXlXlXkXxXiXOX~.jXzXNX2X  y [.NXhXlXlXlXzXzXy.  >.lXlXkXlXlXlXlXlXlXjXBXG.    p.NXdXjXlXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   L rXa.: ] sXcXlXlXjXxXwXb   x.nXbXg.  n eXxXjXlXlXkXbXwXU : g.dXzXkXlXlXlXlXlXjXbXQ.;   y.KXNXCXNXzXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   U 1X#XN . eXmXkXlXlXgXZX2.  * o.o.$   0.ZXgXlXlXlXjXVX-X  A ).wXcXkXlXlXlXlXjXzXrXm   1 ,.>.<.*.f.wXcXkXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   Y -XgX_   D.xXlXlXlXkXxXrX:.=     * 3.iXlXkXlXlXlXzXzXj.  { -X8XvXkXlXlXlXlXhXnX@X2             * *XnXhXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   Y :XeX_.5 6 dXzXlXlXlXjXnXfX.XW.E..XhXbXjXlXlXlXkXbX9X% d E..X0XvXkXlXlXlXlXkXzXpX).K.U.R.E.E.Y.].aXzXkXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   Y <X1XGXW   &.BXkXlXlXlXjXzXCXFXFXCXzXjXlXlXlXlXxXcX)   *.lX/.eXvXkXlXlXlXlXlXlXxXAXGXFXFXFXFXGXAXxXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   Y <X4XmX1X7 o c.BXlXkXlXlXkXjXhXhXjXkXlXlXlXkXxXmXr.  g yXeX_.eXvXkXlXlXlXlXlXlXlXhXhXhXhXhXhXhXhXlXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   Y <X6XxXnX_.& $ x.nXvXlXjXkXlXlXlXlXlXkXjXzXnXcXr.  5 +XBX0X'.eXvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.5X~   O                                             o   Y <X5XvXkXnXC.:   $.wXxXVXvXlXjXhXkXzXbXCXzX7X_   6 T.mXxXwX'.eXvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX0X}.OXoXoXoX",
"oXoXoX}.4X/   $ O O O O O O O O O O O O O O O O O O O O O O #   E <X5XcXjXkXmX).y   2 m.=XrXxXBXDXNXzXqX&Xh.$   h +XmXjXcXqX'.wXcXjXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXjXcX9X|.OXoXoXoX",
"oXoXoX{.7XI                                                     D 2X7XMXcXvXxXCX6X@.i     ! u.N.K.m.r.U     f -.tXBXxXcXMXrX`.tXMXcXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXcXMXwX}.OXoXoXoX",
"oXoXoX.X*Xq.I / ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ / U 8.$X>XwX9X0X0X7XeXgXH.[ V &           ; S  .E.jXqX7X0X9XwX1X|.1XwX9X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X9XwX,XoX+XoXoXoX",
"oXoXoXOX}.*X7X4X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X4X7X=X|.oX}.|.}.}.|.{.'.$X<X_.k.4.>.;.>.6.c.{.<X@X`.{.|.}.|.}..X#X.X}.|.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.|.}.oX.X XOXoXoX",
"oXoXoXoX+X.X{.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.{..X+XOXOXOXOXOXOXOXOX.X|.+X;X1X3X3X3X1X-XOX|..XOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOX+X X XOXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXXX X|.|.|.|.|. XXXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXOXOXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX"
};

/* XPM */
static const char *const xpm_icon_2[] = {
/* columns rows colors chars-per-pixel */
"88 88 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXOXoXXXXXXXXXXXXXXX X XoX@X#X#X#X@XOX.X X.XXXXXXXXXXXXXoX@X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#XoXoXXXXXXXXXXXXX.X X.XOX@X#X#X#X@XoX X XXXXXXXXXXXXXoXoXoXoXoXoX",
"oXoXoXoX+X@X@X@X@X@XOXoX-X>X@X{.'.'.'.[.XX-X>X@XoX@X@X@X@X#X}.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(./.[.@X@X@X@X@X@XoX@X>X-XXX[.'.'.'.{.@X>X-XoXOX@X@X@X@X+XOXoXoXoXoX",
"oXoXoXXX@XzXzXzXzXjXvXZX4XW.X.2       $ D N.#XcXVXhXzXlXvX8X:Xh                                               - oX3XbXkXzXzXhXVXcX#XN.D #       3 X.W.4XZXvXjXzXlXvX-X.XoXoXoXoX",
"oXoXoXXX@XzXlXlXjXmXtXk.r   * K ` ..{ Q y     *.@XVXjXkXvX8X;Xk   X                                           : oX3XvXkXkXjXVX@X=.    u Q { ..` K *   t j.yXmXjXkXvX-X.XoXoXoXoX",
"oXoXoXXX@XzXlXjXNX=XV   p l.{.iXnXHXVXhX=XG.^   , B.MXkXcX8X;Xk   X                                           : oX3XvXjXlXMXB.,   ( G.=XhXVXHXnXiX{.l.u   V -XNXjXvX-X.XoXoXoXoX",
"oXoXoXXX@XzXjXNX`.w   7.qXCXVXlXfXaXdXkXmXFXgXT.9   w.xXvX7X;Xk   X                                           : oX3XvXkXcXw.  9 R.hXFXmXkXdXaXhXxXCXCXqX7.  w `.MXzX-X.XoXoXoXoX",
"oXoXoXXX@XjXmX=Xw $ H.VXbXgXfXbXAXSXCXzXfXgXzXCX1XN   c.CX6X:Xk   X                                           : oX3XcXmXc.  N 1XCXzXgXhXhXCXDXnXjXhXgXbXVXG.$ w =XBX&X.XoXoXoXoX",
"oXoXoXXXOXvXtXB   H.ZXkXjXlXmX<X^.Q.[.iXMXjXkXgXNX5Xh . ].yX-Xk   X                                           : oX1XCX^.X j 5XNXgXkXkXkXbX_.L.<XbXkXlXjXkXZXG.  V aX>X|.oXoXoXoX",
"oXoXoXXXoXZXk.  7.VXkXlXlXvXU.t       Q 3XnXjXlXgXCX{.O B wX-Xk   X                                           : XX1XBXb O {.CXgXlXkXzXMXd.    t.GXfXlXlXlXkXVX7.  x.7X}.oXoXoXoX",
"oXoXoX X-X4Xt i qXbXjXlXcXeX-   o.M.M   @.VXhXlXzXgXAXO.$ e.qXf   X                                           : |.iXN.o +.AXgXzXkXlXgX4.  - o j.DXgXlXlXlXjXbXqXy p ^.$XXXoXoXoX",
"oXoXoX X>XW.  l.CXgXlXkXvX$Xa o.fXDX>X  V rXcXkXlXlXxX7X  A 0Xf   X                                           : |.tX(   9XxXlXlXjXmX>X5 ..O.  h.FXfXlXlXlXlXhXCXj.  k.*XXXoXoXoX",
"oXoXoXoX@X .* {.CXhXlXlXlXkXzXlXmXNXW.  P kXlXkXlXlXxXkXV 6 `.c   X                                           - %X^.a B lXxXlXlXlXkXcX4XkX-.  h.FXfXlXlXlXlXhXCX[.= W oXOXoXoXoX",
"oXoXoX@X{.2 K iXzXkXlXlXlXlXkXMX.X2.3 5 P.CXhXlXlXlXlXvXh.  b.V   X                                           * 1Xa.  k.vXlXlXlXlXlXlXcXmX$.  h.FXfXlXlXlXlXkXxXuXJ > [.@XoXoXoX",
"oXoXoX#X'.  ' mXjXkXlXlXlXlXdXPX$.    ~ bXkXkXlXlXlXkXMXT.  s.A   X                                           * 4X6.  E.MXkXlXlXlXlXlXkXnX$.  h.FXfXlXlXlXlXkXjXnX`   '.#XoXoXoX",
"oXoXoX#X'.  ..HXfXlXlXlXlXkXgXcX3XG.v   9.BXhXlXlXlXjXVX X  p.A   X                                           * 5X2.   XVXjXlXlXlXlXlXkXnX$.  h.FXfXlXlXlXlXlXfXHX..  '.#XoXoXoX",
"oXoXoX#X'.  { VXhXlXlXlXlXnXZXvXcXSX:XX e >XnXjXlXlXkXNX/.  a.A   X                                           * 5X4.  /.NXkXlXlXlXlXlXkXnX$.  h.FXfXlXlXlXlXlXhXVX{   '.#XoXoXoX",
"oXoXoX@X[.$ Q hXlXkXlXlXcX-XK.;XMXhXcXc & '.VXhXlXlXkXnXV.  k.C   X                                           * 2Xe.  Z.nXkXlXlXlXlXlXkXnX$.  h.FXfXlXlXlXlXkXlXgXE + ].#XoXoXoX",
"oXoXoXOXXXD u =XmXjXlXkXMXs.  A gXNX`.O e -XmXjXlXlXzXlX[ & U.n   X                                           = -XD.3 } lXzXlXlXlXlXlXkXnX$.  h.FXfXlXlXlXlXjXmX&Xy b .X+XoXoXoX",
"oXoXoX.X-XN.  G.FXgXlXlXcX0Xe   z T 4   :.MXhXlXlXlXcXfX@ c <Xh   X                                           ; XX2XI O gXcXlXlXlXlXlXkXnX#.  g.FXfXlXlXlXlXgXFXD.  0.%XXXoXoXoX",
"oXoXoX X>X$X  ^ gXzXkXlXkXbX#XW o   7 r.sXcXkXlXlXhXBXn.  | tXd   X                                           : }.dX4.  M.BXhXlXlXlXlXkXnX%.  j.FXfXlXlXlXkXxXgX!   J.*X.XoXoXoX",
"oXoXoXXX+XvX-.  T.CXgXlXlXkXnXlXdXdXfXcXcXkXlXlXhXcXiX7 t +X,Xh   X                                           : .X5XeX0 9 pXcXhXlXlXlXlXlXdXiXgXzXlXlXlXlXgXCXU.  :.:X XoXoXoXoX",
"oXoXoXXXoXVX@X, 8 1XNXgXzXlXkXzXcXcXcXlXkXlXlXhXlXbX]   d.sX=Xk   X                                           : oX<XGXt.  { nXlXhXlXlXlXlXxXvXzXlXlXlXzXgXBX,X6 < *X5X}.OXoXoXoX",
"oXoXoXXX@XhXVXB.  M 5XZXgXlXlXlXlXlXlXlXlXlXhXcXbX1.  / nX8X;Xk   X                                           : oX3XvXzX^   2.nXcXhXlXlXlXlXlXlXlXlXlXgXZX3Xm   V.SX%X.XoXoXoXoX",
"oXoXoXXX@XzXjXMXw.  g [.AXxXxXlXkXjXkXkXzXcXBXiX[   C tXnX7X;Xk   X                                           : oX3XvXxXtXV   [ iXBXcXzXkXkXjXkXlXxXxXAX].g   r.MXzX-X.XoXoXoXoX",
"oXoXoXXX@XlXkXkXxXc.. X o.7XkXvXMXVXNXnXlXfXn.7   / tXlXzX7X;Xx   @ O O O O O O O O O O O O O O O O O O O O   1 oX3XcXhXzXrX~   8 m.fXlXnXNXVXMXvXkX7XX.X X v.xXjXxX-X.XoXoXoXoX",
"oXoXoXXX@XvXvXcXvXCX].V $   B h.T. X/.V.{ @   t s.bXnXzXmX0X>Xy                                               . OX4XMXxXxXnXbXs.y   @ } C./. XT.h.B   # B [.CXvXxXMX-X XoXoXoXoX",
"oXoXoXXX@XeXwXeXwXqXaXiXi.H 9           * M O.*XjXwXwXwXtX1X@X@.J T Y Y Y Y Y Y U P L K K L P U Y Y Y Y Y Y I / }.:XtXwXeXwXwXjX&Xo.M ;           w J p.iXaXqXwXwXtX&XXXoXoXoXoX",
"oXoXoXoXOX].].].].].`.`.%X*XE.x.s.p.a.h.G.oX;X{._.].].].'. X X-X2X<X<X<X<X<X<X1X6XtXpXaXaXpXtX6X1X<X<X<X<X<X1X>X XXX'.].].].]._.}.;X|.b.7.<.>.2.e.J.&X&X`.'.].].].'.oX@XoXoXoXoX",
"oXoXoXXX@XaXpXpXpXiXpXgXdX5Xm._ F N A R 9.+XpXgXdXuXpXiXdX7X|.8XtXeXeXeXwXuXaXrXI.) z u u x _ I.rXaXuXwXeXeXrXwX.X,XdXiXpXpXpXpXiXrXuXjXvXnXnXnXcXfXtXtXpXpXpXpXiXdX*X.XoXoXoXoX",
"oXoXoXXX@XcXxXcXlXvXmX<X_ $ $ : ; & - > * + g W.zXNXlXzXnXrX'.sXbXxXzXzXNXiXi.< $ > 1 : : 1 > # 1 i.uXBXzXzXvXlX}.4XmXzXxXxXxXxXxXxXxXlXkXkXkXkXkXzXxXcXxXxXxXxXxXnX-X XoXoXoXoX",
"oXoXoXXX@XlXlXjXvXfX8.  # V 8.OXwXcXaX>XM.R 9   H >XMXhXcXwX].pXxXjXlXmXI.7   g X.!.6XkXkX6XQ...g   6 U.mXlXkXhX}.3XvXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcX-X.XoXoXoXoX",
"oXoXoXXX@XzXkXbX0X(   N P.BXSXbXxXlXzXcXBXKX&Xo.  0 `.vXcXwX].pXzXlXkXf.  3 p.aXHXnXcXlXlXcXnXJXpXi.3   g.kXxXhX}.3XvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoXXX@XkXxXgXY   $.pXSXgXgXkXkXzXxXzXjXfXmXCXZ.; - oXVXqX].pXzXmXf.  N #XHXlXfXjXkXxXxXkXjXfXlXGX#XN   g.MXgX}.3XvXkXlXlXlXlXlXlXlXkXzXxXxXzXkXlXlXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoXXX+XkXvX$.  :.cXbXfXlXlXlXzXkXgXgXkXlXhXhXZXT.= r wXtX'.iXNXI.  N 5XCXfXkXkXlXvXgXgXkXlXlXkXfXCX4XM   T.bX{.3XvXkXlXlXlXlXlXkXzXbXlXkXkXzXbXlXlXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoXXXXXSXI.  I kXcXjXlXlXlXgXZX|   p :XbXjXkXgXSXj.  [ jX).fXiX5 3 #XVXgXlXlXxXmXj.o 5 -XMXjXlXlXfXCX@X3 9 eXXX3XvXkXlXlXlXlXlXkXcXP.v   O H }.vXkXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX.X%XiXI . *XBXjXlXlXlXhXBX}.1   q ;XbXjXlXlXjXVXV 1 P.oXfXp.  i.GXfXlXlXlXjXe.    - *XNXjXlXlXlXfXHXp.  e.+X3XvXkXlXlXlXlXhXVXW.+ . V x   , -XmXkXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX X,X{.  4.bXkXlXlXlXlXhXMX .    w ;XbXjXlXlXkXbX}.  W ;XyX< g pXlXkXlXhXBXC.  T d % -XNXjXlXlXlXkXzXiXh :  X3XvXkXlXlXlXkXlXlX(   7.nXgX_   h.bXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoXXX&Xw.  W.DXgXlXlXlXhXVX|.O S # 9 ;XbXjXlXlXlXxXjXq f `.W.@ X.HXfXlXlXkXvX>XA.2Xb # ;XNXjXlXlXlXlXfXHXX.O x.8XcXkXlXlXlXlXzXhXOXJ.pXjXKXb.  <.xXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX+X|.a M 7XcXjXlXlXkXzXzX+.  !.4 4 :XbXjXlXlXlXlXzX6.  N.#.- !.nXjXlXlXlXkXnXAX0Xk $ ;XNXjXlXlXlXlXjXnXQ.: Q tXxXkXlXlXlXlXlXzXBXFXzXgXNX-.  z.nXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X].  ) cXkXkXlXlXkXmX$X  U sX: 5 :XbXjXlXlXlXkXmXJ.  d.K > 7XcXkXlXlXlXlXhXvX8Xl $ ;XNXjXlXlXlXlXkXcX5X1 z iXzXkXlXlXlXlXlXlXjXhXgXCX~.O > <XmXkXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X'.   .FXgXlXlXlXzXnX'   H.ZX$ 6 ;XbXjXlXlXlXjXBX[.  p.B * lXlXlXlXlXlXlXkXbX9Xl $ ;XNXjXlXlXlXlXlXlXlX> p pXzXkXlXlXlXlXlXlXlXjXMX%X8   Z.mXjXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X'.   .DXgXlXlXkXbX+X  Y bXcX= 6 <XbXjXlXlXlXjXBX[.  p.B * kXlXlXlXlXlXlXkXbX9Xl $ ;XNXjXlXlXlXlXlXlXkX> p pXzXkXlXlXlXlXlXlXjXnX6Xh   0.mXkXkXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X].  ( xXkXkXlXjXNX9.  = f y +   W rXcXkXlXlXkXmXJ.  d.K > 6XcXkXlXlXlXlXkXbX9Xl $ ;XNXjXlXlXlXlXkXcX4X2 z iXzXkXlXlXlXlXlXjXvXiXS   X.zXjXjXlXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX+X Xs M 7XcXjXlXkXMXa.6 3 ; > O   F wXcXjXlXlXlXzX5.  N.$.; !.nXjXlXlXlXlXkXbX9Xl $ ;XNXjXlXlXlXlXjXnXE.: Q tXxXkXlXlXlXlXkXzXdX^   ] BXZXBXnXlXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoXXX&Xe.  W.DXgXlXlXlXbXBXBXCXVX< e 5XnXjXlXlXlXxXjX9 g `.Q.@ ..JXfXlXlXlXlXkXbX9Xv ; :XNXjXlXlXlXlXfXJX .O c.8XcXkXlXlXlXlXkXnXq.  2 x.H.Z.V.$XzXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX X,X{.  3.bXkXlXlXlXkXjXjXjXjX  o *XbXjXlXlXkXbX}.  Q ;XyX1 g pXzXkXlXlXlXkXnX7X0   *XBXjXlXlXlXkXzXiXh :  X3XvXkXlXlXlXkXxXsXH             @.vXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX.X%XiXI   *XBXjXlXlXlXlXlXlXlXJ.I.iXxXkXlXkXjXBXN 1 I.oXfXa.  i.GXfXlXlXlXlXxXdXQ.H.uXcXkXlXlXlXfXGXy.  r.+X3XvXkXlXlXlXlXlXkX|.C.F.J.K.K.F.*XzXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoXXXXXSXU.  P kXvXhXlXlXlXlXlXlXDXSXxXlXlXkXgXSXf.  } jX).fXiX7 2 @XCXfXlXlXlXlXzXAXFXxXkXlXlXlXgXCXOX1 q eXXX3XvXkXlXlXlXlXlXlXVXGXFXFXFXFXGXMXlXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoXXX+XkXbX%.  ;.cXbXfXlXlXlXlXlXgXhXkXlXhXhXZXU.* y eXtX'.iXBXY.  M 4XCXfXkXlXlXlXhXgXkXlXlXkXfXCX3Xn   R.bX{.3XvXkXlXlXlXlXlXlXjXgXgXgXgXgXgXjXlXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoXXX@XkXxXgXT   #.iXSXgXgXkXkXlXlXkXhXfXmXVXV.- ; OXVXqX].pXzXmXg.  M @XGXzXfXjXkXlXlXkXjXfXzXGX+Xm   h.NXgX}.3XvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoXXX@XzXkXvX0X)   m K.NXSXbXxXlXzXvXBXJX&X..  q '.vXcXwX].pXzXlXkXg.  1 u.iXHXnXcXlXlXcXnXJXiXu.1   h.kXxXgX}.3XvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcX-X.XoXoXoXoX",
"oXoXoXXX@XxXzXkXnXhXq.  # V 7.XXwXvXaX:Xm.R 9   L ,XNXjXvXeX].aXvXkXxXMXT.0   h ..W.5XlXlX5XW...h   9 R.NXxXzXkX}.4XbXlXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXlXbX-X XoXoXoXoX",
"oXoXoXXX#XsXsXsXpXdXjX%XW   X = ; & = ; @   y L.pXkXiXaXgX9X{.uXlXhXhXgXbXeXr.; o * : * * : * o : t.eXbXgXgXkXfX|.2XxXhXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXhXzX=X.XoXoXoXoX",
"oXoXoXoXXX1X1X1X1X<X1X6X8X=Xz.) F N Z T 5.{.6X7X3X,X1X<X2X*XXX.X}.}.}.}.{.XXXX[.n.| H B B H | m.[.XXoX{.}.}.}.|.@XXX}.|.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.|.}.OX+XoXoXoXoX",
"oXoXoX+X).:.>.>.>.>.>.:.>.,.6.w.r.t.r.e.8.1.>.:.>.>.>.<.*.h.@X>X4X3X3X3X3X,XqXdX&XA.g.p.p.g.S.&XdXqX,X3X3X3X4X2XXX*X5X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X5X$XoXoXoXoXoX",
"oXoXoX#X(.                                                S 2XyXmXvXvXcXmXGX{.o.N +         + N o.{.GXmXcXvXbXxX}.5XNXcXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXcXMX-X XoXoXoXoX",
"oXoXoX#X(.X + + + + + + + + + + + + + + + + + + + + + $   E <XwXzXjXjXnX6X) :   9 7.K.[.[.K.6.8   ; ( 8XnXjXlXhX|.3XcXjXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXjXxX=X.XoXoXoXoX",
"oXoXoX#X(.                                            O   Y <XeXxXjXbXoXt   C .XkXxXmXBXBXmXxXkX XV   t OXvXkXhX}.3XvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   Y <XeXlXMX`.- = j.VXbXjXdXdXsXsXsXgXcXbXVXj.- - `.NXfX}.3XvXkXlXlXlXlXlXlXlXkXgXdXfXgXkXlXlXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   Y <XqXMX;X9 : T.SXjXlXFXPXLXLXLXPXHXkXkXjXSXT.; 9 ,XvX{.3XvXkXlXlXlXlXlXlXkXcXDXLXLXAXzXkXlXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   Y <XyXzXF   A.ZXfXlXfX=.G U P P G o.nXkXlXgXAXZ.  L gX.X3XvXkXlXlXlXlXlXjXMX3X3.Y W u.uXbXjXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   Y <XpXQ.  o.CXhXjXlXaXy           w BXjXlXkXhXCXO.  U.OX3XvXkXlXlXlXlXjXMX*Xk         G eXvXkXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   Y <XpXg 9 *XmXhXkXlXsXz . [.9X4X6XeXzXlXlXlXhXmX&X0 a OX3XvXkXlXlXlXlXkXbX#.  R 2XXXx   S.mXkXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   U 4X.X+ R KXfXlXkXlXsXh   pXIXLXSXlXlXlXlXlXlXfXJXE X K.6XvXkXlXlXlXkXzXfXk.K >XmXPXk.  2.xXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   P eX=.- N.NXjXlXkXlXsXl   o...$.Y.mXlXlXlXlXlXhXBXM.* X.eXxXkXlXlXlXlXlXzXSXUXvXdXSXy.  r.vXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   L iXN 1 ,XcXkXlXkXlXaXj         # z.MXkXlXlXlXkXvX:X1 m iXzXkXlXlXlXlXlXlXgXsXgXMX3Xi   }.MXkXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   L aXa , sXzXlXlXkXlXsXN   7.uXx.  2 rXzXkXlXlXlXzXaX, s pXzXkXlXlXlXlXlXlXlXkXcXsXU   -.xXzXkXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   K aXy ; cXlXlXlXlXlXjX@X{.jXvXFXM   U.NXjXlXlXlXlXcX: i pXzXkXlXlXlXlXlXlXkXzXlX|   Y aXcXjXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   L pXg < wXxXkXlXlXkXcXLXIXkXfXDXR   M.VXhXlXlXkXxXqX1 h pXzXkXlXlXlXlXlXkXkXnX3.  x 8XnXhXlXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   L uXK < OXbXkXlXkXcX9X8.,.vXzXGXM   I.NXjXlXlXkXbXXX, F uXzXkXlXlXlXlXlXjXNXf.  t <XZXlXxXlXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   I 9Xh.& 8.SXgXlXkXkXhXd   7.eXl.  < rXxXkXlXlXgXSX6.# 0.0XcXkXlXlXlXlXjXmXD.X = T.pX5X8XiXlXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   Y 2X4X$ V BXgXlXlXhXVXK.1       @ x.mXkXlXlXlXgXNXV + ).4XvXkXlXlXlXkXxXgXI             3.vXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   Y <XaX' @ K.SXfXlXlXkXNX}.@.U ] W.mXlXlXlXlXfXSXJ.@ / +X3XvXkXlXlXlXlXzXgXs.J W I U T G S.xXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   Y <XpX1X  M iXbXhXlXlXjXnXHXPXJXNXkXlXlXlXhXbXuXn   -XOX3XvXkXlXlXlXlXlXlXAXIXLXPXPXLXIXVXlXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   Y <XeXmX9.  $.cXvXjXlXlXjXfXdXfXhXlXlXlXjXvXcX+.  w.cX}.3XvXkXlXlXlXlXlXlXgXdXdXdXdXdXdXhXlXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   Y <XwXvXgX)   ;.kXBXkXgXjXkXlXlXkXjXgXkXBXjX=.  _ jXkX{.3XvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.                                            O   Y <XeXlXvX0XT   L &XbXDXvXkXgXgXkXvXDXbX&XK   R qXnXfX}.3XvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX-X.XoXoXoXoX",
"oXoXoX#X(.. O O O O O O O O O O O O O O O O O O O O O #   R <XeXxXhXvXfX%.    2.R.6XzXDXDXzX5XR.2.    &.gXcXjXhX|.3XcXjXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXjXcX-X.XoXoXoXoX",
"oXoXoX#X(.                                                F 2XtXnXcXxXbXNXE.R     m /  . ./ n     R E.NXbXxXbXzX}.5XMXxXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXcXmX-X XoXoXoXoX",
"oXoXoXOX_.n.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.M.v.G.oX*X-X-X-X*X*X8XXXB.%.e         e &.V.XX8X*X*X-X-X=XOX$X-X=X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X@XOXoXoXoXoX",
"oXoXoXoXOX;X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X;X%XoXXX X.X.X.X X{.OX=X@X}.].'.'.].}.#X=XOX{. X.X.X X.X+XoX X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X XOX].oXoXoXoX",
"oXoXoXoXoX.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.XXXoXoXoXoXoXoXoXoXXX.XoX@X#X#X#X#X@XoX.XXXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX"
};

/* XPM */
static const char *const xpm_icon_3[] = {
/* columns rows colors chars-per-pixel */
"64 64 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoX.X.XXXXXXXXX.X.XoXoXoXoXoXoXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXoXoXoXoXoXoXXX X.XXXXXXX.X XXXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXOXXXXXXX.X|.=X>X*X*X*X*X>X=X|..XXXXXXXoX$X#X$X$X$X$X$X$X$X$X$X$X$X$X#X$XoXXXXXXXXX|.oX>X;X&X*X&X-X,X+X|.XXXXXXOXoXoXoXoX",
"oXoXoXoXXXyXfXpXhXMX|.<.h < < j <.|.MXhXpXsX8X ., e 0 0 0 0 0 0 0 0 0 0 0 0 e ,  .8XsXsXpXnXaXZ.! 0 > 7 P c.wXMXpXdXyXoXoXoXoXoX",
"oXoXoXoXXXfXzXNXiX` - c e.Z.Z.e.c = ` iXNXjXrXT                                 T rXzXkXSXQ.s < _ c.D.n.X.5 9 B.ZXcXdXXXoXoXoXoX",
"oXoXoXoXXXpXNX<Xt g  XVXBXZXZXBXCX|.g t <XmX0X!   + X X X X X X X X X X X X +   ! eXhXBXd.X -.aXZXVXAXZXZXkXy.@ -.NXsX.XoXoXoXoX",
"oXoXoXoX.XhXuXt E mXVXzXMXnXmXnXhXCXmXR t yXyXW   o                         o   Q qXVXB.o P.KXxXhXmXcXkXhXlXJXoX& 0.bX XoXoXoXoX",
"oXoXoXoX|.MX` g mXxXlXrX{ 1 d P.mXfXcXmXg ) kXR   o                         o   E iX5X# c.JXfXjXAXi.2 W.CXhXfXFX^.o _.=X.XoXoXoX",
"oXoXoX.X=X|.-  XVXsXSX{   l.W O 2XbXfXCX|.& (.]   o                         o   T xX| N VXjXjXmX1.+   C.SXhXlXgXFX] M ;X.XoXoXoX",
"oXoXoX.X>X,.c CXhXlXcX!.'.UX%X  {.NXjXhXVXl >.|   o                         o   ~ 7Xq M.DXgXlXzXN.K.3 C.SXhXlXhXVX].; E.#XXXoXoX",
"oXoXoXXX*Xh r.CXjXlXkXVXZXs.8 Q zXlXlXjXCX8.N ]   o                         o   { K.7 3XbXkXlXjXJX5X% Z.SXhXlXkXxXaXd 5.,X XoXoX",
"oXoXoXXX*X< A.AXhXlXlXsXzX[   X.mXkXlXhXAXB.y ]   o                         o    .n.2 zXlXlXlXjXbX>X& Z.SXhXlXlXjXZXx +.2X XoXoX",
"oXoXoXXX*X< Z.AXhXlXlXSXMXDX_.  U.VXjXhXAXB.y ]   o                         o    .n.2 zXlXlXlXjXmX,X& Z.SXhXlXlXjXZXx +.2X XoXoX",
"oXoXoXXX*Xh e.CXhXxXgX-.A.UXpX% s.DXhXjXVX8.B ]   o                         o   { L.7 2XbXkXlXjXmX,X- A.SXhXlXkXxXpXd 5.,X XoXoX",
"oXoXoX.X>X<.c CXhXkXNXR   ;.v $ :XnXkXhXVXk ,.|   o                         o   ~ 7Xw m.DXgXlXjXMX:X  M.DXhXlXhXVX].; W.#XXXoXoX",
"oXoXoX.X=X|.= |.CXfXcXgX7.l I {.MXkXgXCX}.& (.]   o                         o   T xX .M VXjXkXkXbX7XY /.VXjXlXgXFX' M ;X.XoXoXoX",
"oXoXoXoX|.MX' g mXcXgXxXAXJXGXmXkXgXcXnXd _ kXR   o                         o   E iX5X$ x.JXfXkXlXxXSXbXkXlXfXFX!.X `.*X.XoXoXoX",
"oXoXoXoX.XhXiXt R mXCXhXfXsXdXgXhXCXnXY y uXyXW   o                         o   Q qXVXV.o P.KXxXhXhXdXgXjXlXJX.X% w.nX XoXoXoXoX",
"oXoXoXoXXXpXNX<Xt f }.VXCXAXAXCXVX}.d y <XnX0X~   @ o o o o o o o o o o o o @   ! wXhXBXd.X *.iXZXZXSXZXCXjXr.+ ;.NXaX.XoXoXoXoX",
"oXoXoXoXXXhXcXVXsX[ ; x 9.B.B.9.x ; [ sXVXzXtXI                                 I tXcXzXFX^.f 1 ) c.F.m.X.6 w Z.SXbXgXXXoXoXoXoX",
"oXoXoXoXOX&X=X%X;X5XG.@.N p p N #.G.5X;X%X*X%XZ.u.d.s.p.a.k.B.S.D.A.b.g.i.a.d.u.Z.&X*X*X%X6X&Xt.G 5 = 2 B 6.XX8X%X*X*XOXoXoXoXoX",
"oXoXoXoXoX4X8X6X5XiXiX(.@.T T #.(.iXiX5X6X9X#X5XhXaXiXcXxX%X9./ W } Z.eXmXgXiXhX5X#X9X7X7X4X8XsXaXuXiXuXpXdX0X4X7X8X4XoXoXoXoXoX",
"oXoXoXoXXXhXvXnXCXG.i < G ~ ~ G < i G.ZXbXmX-X7XbXjXAXoXF & n W ! I w , 5.gXMXxX8X=XMXcXvXvXcXzXxXcXcXcXxXzXcXvXvXnXhXXXoXoXoXoX",
"oXoXoXoXXXaXcXkX' O 9.4XvXFXZXzX4X8.O ] kXbX&X7XxXNXl.X ^ #XhXCXSXNXtXS.7 f 2XVX4X=XcXkXkXkXkXkXjXfXfXgXkXkXkXkXkXzXsXXXoXoXoXoX",
"oXoXoXoXXXsXNX! 8 >XGXnXkXlXGXCXbXGX>X7 ! VX*X4XFXl.X D.GXMXkXVXSXlXcXAXlXY 9 tXwX&XvXkXlXlXlXkXvXHXPXZXlXlXlXlXlXxXsXXXoXoXoXoX",
"oXoXoXoX}.NXt.- 6XCXfXhXbX3X{ C.vXdXCX6X- p.7XrX@XX F.JXfXkXZXv.$.yXxXfXvXBXV H yX&XvXkXlXlXkXmX8X,./ V.xXzXlXlXlXxXsXXXoXoXoXoX",
"oXoXoXXX#X2X3 N.GXfXlXhXZX$.  ) NXkXdXGXN.4 ).sXH ~ GXfXkXzX<.  X 3XnXkXhXMX4X< k.6XzXkXlXkXcXeX3 1 H   q.ZXhXlXlXxXsXXXoXoXoXoX",
"oXoXoX X,Xa.w bXkXlXjXmX=X5    .MXjXlXkXvXw 2.&X& #XMXhXbX5X_ =.4 5XnXkXlXgXHX| c 9XzXkXlXjXmX@XM &XUX^ u xXzXkXlXxXsXXXoXoXoXoX",
"oXoXoXXX=XZ ;.CXjXlXhXSX( J N W VXjXlXjXCX&.H 5.m jXzXkXlXkXLXA.& 6XnXkXlXjXVXT.5 |.mXjXlXlXkXvXFXzXFXI c mXkXkXlXxXsXXXoXoXoXoX",
"oXoXoXXX&X4 B.AXhXjXMX;XX .XZ E VXjXlXhXAXb.d W ! SXhXlXlXhXCXn.* 6XnXkXlXkXbX5X& Q.BXjXlXlXlXkXaXAXS.  J.CXhXlXlXxXsXXXoXoXoXoX",
"oXoXoXXX*X> S.SXhXjXZX` N PXl Q VXjXlXhXSXC.i Y ^ JXgXlXlXhXZXM.* 6XnXkXlXkXvXwX# W.VXjXlXlXlXhXCX`.  <.VXjXlXlXlXxXsXXXoXoXoXoX",
"oXoXoXXX*Xr j.CXgXcXiX6   3 X + `.NXjXjXCXs.z ' Y NXkXlXlXhXAXM.= 6XnXkXlXkXnX&X; ^.BXjXlXlXjXNX-X* X.LXmXlXlXlXlXxXsXXXoXoXoXoX",
"oXoXoX.X;X{ U ZXhXzXhX'.H.W.q b iXxXkXhXZXP ` Z.e tXvXkXlXhXAXn.$ 6XnXkXlXgXFXg.e -XvXkXlXkXcXqX7 6 {.`.+XlXlXlXlXxXsXXXoXoXoXoX",
"oXoXoX X:XI.; 9XbXjXzXCXZXUXZ } SXjXjXbX8X: k.wX< S.AXgXlXhXZXC.4 7XnXkXlXjXBXB ! eXlXkXlXjXBX/.# : %   D kXzXkXlXxXsXXXoXoXoXoX",
"oXoXoXoX.XkXn ( HXhXjXhXhXhXiXpXlXkXhXHX/ M ;XsX9.7 lXvXhXlXzXgXuXkXlXkXfXHXC.-  X,XxXkXlXlXlXjXiXyXuXiXaXlXlXlXlXxXsXXXoXoXoXoX",
"oXoXoXoX XcX+X# f.JXxXgXjXkXxXlXfXxXJXs.# $X2X7XkXd U BXMXgXhXlXxXkXgXjXHXoX# j.aX%XvXkXlXlXlXzXcXcXcXvXcXlXlXlXlXxXsXXXoXoXoXoX",
"oXoXoXoXXXiXAXJ.o =.hXHXMXvXvXMXHXhX*.O J.DX$X5XVX2X9 V 3XHXVXbXcXnXFXBXC.# &.AX5X*XcXkXkXkXkXkXkXkXkXjXkXkXkXkXkXzXsXXXoXoXoXoX",
"oXoXoXoXXXdXlXCX'.9 e ,.'.7X7X'.,.e 9 ].CXxX*X0XnXVXtXH < } U.2X9X#Xf.B - h.AXMX8X=XMXcXvXvXvXvXvXvXvXvXvXvXvXvXvXnXhXXXoXoXoXoX",
"oXoXoXoXXXyXfXiXcXiX0.m t 4 4 r m 0.iXcXiXgX=X;X0X4XwXyXh.x t 7 4 0 p E }.aX5X8X:X$X9X7X7X7X7X7X7X7X7X7X7X7X7X7X7X8X4XoXoXoXoXoX",
"oXoXoXoXXXl.p.d.p.d.B.c.2.=.=.2.c.B.d.p.d.u.E.=X*X=X$X=XsXuXz.$.O.,._.zX8X#X&X=X$X@X=X*X*X*X*X*X*X*X*X*X*X*X*X*X*X=X&XOXoXoXoXoX",
"oXoXoXXX$X<                                 u.gXbXlXCXzXu.s y t e y r G {.SXvXmX9X=XMXcXvXvXvXvXvXvXvXvXvXvXvXvXcXnXhXXXoXoXoXoX",
"oXoXoXXX#Xe   O o o o X X . . X X o o o @   d.sXhXMX$Xr 0 w.XXaXkX9XU._ o @.xXbX5X*XcXkXkXkXkXkXkXhXgXjXkXkXkXkXkXzXsXXXoXoXoXoX",
"oXoXoXXX$X0   X                         o   s.iXVX.X* } hXIXPXFXDXHXGXDX X5 T NX7X*XvXkXlXlXlXkXlXCXDXmXjXlXlXlXlXxXsXXXoXoXoXoX",
"oXoXoXXX$X0   X                         o   a.jXeX4 $.FXnX,XK.K.K.D.7XlXZX9X1 <.sX%XvXkXlXlXkXcXzX`.J.,XMXkXlXlXlXxXsXXXoXoXoXoX",
"oXoXoXXX$X0   X                         o   p.nX+.f NXhXVXd.  = = . (.CXaXSX^.* Q.1XxXkXlXlXlXkX^   % & I.BXjXlXlXxXsXXXoXoXoXoX",
"oXoXoXXX$X0   X                         o   h.7X= Q.CXdXAXg.: nXKXvXjXlXlXhXSXL J eXlXkXlXjXMXXX  A.NXc z nXlXkXlXxXsXXXoXoXoXoX",
"oXoXoXXX$X0   X                         o   m.z.a pXcXgXZXj.@ 8.0.-XMXjXlXhXSXm.0 $XnXjXlXlXzXfXpXlXUX..p xXzXkXlXxXsXXXoXoXoXoX",
"oXoXoXXX$X0   X                         o   A.' T CXjXhXZXf.  e 3 : =XmXjXkXnX:X= ~.BXjXlXlXlXxXlXBX-X  9.SXhXlXlXxXsXXXoXoXoXoX",
"oXoXoXXX$X0   X                         o   D.E ! JXgXkXnX@Xi.gXxX$ ,.AXhXkXvXeX# W.VXjXlXlXlXhXbXtX6 Z xXzXkXlXlXxXsXXXoXoXoXoX",
"oXoXoXXX$X0   X                         o   S.) R ZXjXlXlXjXVXbXDXz ) VXjXkXbX1X* !.BXjXlXlXkXvXjXk t sXbXjXlXlXlXxXsXXXoXoXoXoX",
"oXoXoXXX$X0   X                         o   M.p.k dXxXhXCXk.< 1X,X  r.AXhXhXZXD.7 OXnXjXlXlXlXlXE < 5XnXfXlXlXlXlXxXsXXXoXoXoXoX",
"oXoXoXXX$X0   X                         o   j.<X& [.BXgXbX4Xd o . c wXvXkXgXFX~ V wXlXkXlXjXBX^.  . 4 . P kXzXkXlXxXsXXXoXoXoXoX",
"oXoXoXXX$X0   X                         o   p.bX^ Z SXjXhXmXpXR.R.pXnXkXgXCX+X= D.4XxXkXlXkXcXqXW.I.H.F.`.lXlXlXlXxXsXXXoXoXoXoX",
"oXoXoXXX$X0   X                         o   p.zX<X& u.JXkXfXzXAXAXzXgXgXNXhXu [ aX%XvXkXlXlXkXvXAXSXDXFXCXlXlXlXlXxXsXXXoXoXoXoX",
"oXoXoXXX$Xw   o X X X X X X X X X X X X O   d.iXCXU.X q.BXAXcXgXdXkXNXFX7Xh c lX9X&XcXkXlXlXlXkXgXgXgXgXhXlXlXlXkXzXsXXXoXoXoXoX",
"oXoXoXXX$X5                                 p.fXlXCX!.: b L.0XNXSXlX&X0.& U sXBX6X=XnXzXxXxXxXxXxXxXxXxXxXxXxXxXzXcXfXXXoXoXoXoX",
"oXoXoXoX@Xn 5 w 0 0 0 0 0 0 0 0 0 0 0 0 e < l.yXdXiXbX2X] = y z x j 3 w v.lXhXfX4X&XhXsXsXsXsXsXsXsXsXsXsXsXsXsXsXfXyXoXoXoXoXoX",
"oXoXoXoX.X@X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$XXXoXXXXX|.#X>X{.u.#.o.;.A.&X;XXX XXXoXOXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXoX.XXXoXoXoX",
"oXoXoXoXOXoXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXoXoXoXoXoXXX.X+X:X2X3X1X&XXX.XoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXXXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXXX.X X X X.XoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX"
};

/* XPM */
static const char *const xpm_icon_4[] = {
/* columns rows colors chars-per-pixel */
"48 48 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXOXOXOXoX.X X X.XoXOXOXOXXX|. X X X X X X X X X X XoXOXOXOXoX.X X X.XoXOXOXOXoXoXoXoXoX",
"oXoXoXoXXX|.|.{.@X>X3X2X;XXX{. X|.$X1X,X<X<X<X<X<X<X<X<X<X>XXX|. X{.XX;X2X3X>X@X{.|. XoXoXoXoXoX",
"oXoXoXXX;X6X6XdX|.5.) ] s.:XsX3X8XA.} +.O.O.O.O.O.O.O.O.X.&.OX8X3XsX:Xs.] ) 5.|.dX7X4X@XXXoXoXoX",
"oXoXOX|.6XBXbX,.m &.d.p.{ b M.DXmX4.                      . $XnXDXM.b { p.f.=.n ,.mXbX#XXXoXoXoX",
"oXoXOX|.6XbXU } sXUXUXUXFX,XN 6.GX8.  @ o o o o o o o O   < +XFX6.N ,XSXUXUXSXdX{ Y xX$X.XoXoXoX",
"oXoXOX{.dX,.} PXNXJ.J 7.dXVXcXv R.d.  o               .   = 3XY.v vXBXcX0.u.nXzXIX} -.6X|.oXoXoX",
"oXoXoX@X|.m sXnXqXk A.x y.CXVX_.H u.  o               .   ; :XG `.CXnXZ.& U AXfXxXfXx E.$XXXoXoX",
"oXoX.X>X5.=.DXhXfXfX4XZ D.ZXhXlXQ `   X               .   6 C.I xXkXkXhXx.W AXjXgXFX&.,.,X XoXoX",
"oXoX X3X) j.FXgXxXJX=.; ,XnXfXZX@.S   .               .   w w.' DXhXgXKXv.I SXhXhXFXj.) 3X XoXoX",
"oXoX X2X] d.DXlXtX:XUX6.( GXdXVXo.G   .               .   w t.` ZXhXhXSXv.R AXhXhXDXs.' 2X XoXoX",
"oXoX.X;Xs.{ AXcX-X8 i.z e.AXjXsXL +.  X               .   3 Y.F fXzXgXFXg.C DXjXgXDX` w.:X.XoXoX",
"oXoXoXXX:Xb ,XNXcX).] f.lXdXKXn.^ f.  o               .   = 4X~ m.LXaXMX}.n.MXdXBX,Xz |.+XoXoXoX",
"oXoXOX{.sXM.M vXZXNXHXZXzXKX=Xp :Xi.  + X X X X X X X o   : >X-Xp -XKXkXvXNXjXAXcXM b.5X|.oXoXoX",
"oXoXOX|.5XHX0.m ].kXNXMXfXB.f W.KX4.                      $ +XJXE.f V.hXZXAXvX].n w.SX@XXXoXoXoX",
"oXoXOX.X<XiXxXN.b R %.@.F G {.zXiXa.4 u w t k n n k t e q k @XuXzX|.G n ~ / S v C.cXtX#XXXoXoXoX",
"oXoXoXXX*X,X-XlX1X%.k b i.pXaX=X;X%X7X3XaX6XV.1.1.V.6XaX4X3X#X<X;X7XeX].M.b.W.7XwX:X,X@XoXoXoXoX",
"oXoXOX|.7XmXZXg.n  .0.4.Q C ~.KXuX<XvXSXD.N Q *.=.Q M S.FXdX:XbXcXzXzXmXCXZXBXxXzXvXcX$XXXoXoXoX",
"oXoXOX|.5XCX .K 1XNXLXUXNX(.g n.cX*XDX6.n @XNXUXUXNX@Xn 8.mX=XzXkXlXjXxXGXDXlXkXkXlXkX$XXXoXoXoX",
"oXoXOX[.dXu.U FXnXvX*X7.tXHXtXk Y.hXA.m bXCXnXh.I.nXBXbXN M.qXkXlXkXbX9X2.e.aXcXkXlXkX$XXXoXoXoX",
"oXoXoXOX#Xb wXnXdXSXR   5XlXDXT.B qXM @XBXbXj.  @.GXaXCX$Xl :XxXkXkXnXB ) H { ZXhXlXkX$XXXoXoXoX",
"oXoX.X:Xw.+.DXdXCX'.a g :XnXjXjXP 4._ NXhXkX9X>.$.GXhXhXVXU N.CXjXzXjX+XUXW.z VXjXlXkX$XXXoXoXoX",
"oXoX X2X_ h.FXfXCX( G.Z 1XnXgXCX$.x q.DXhXgXUX4.X.HXgXhXGX-.6.GXhXlXkXZXdXu M.AXhXlXkX$XXXoXoXoX",
"oXoX X2X_ g.SXmX X# <.> I.BXfXCX$.x 0.DXhXhXDX4.+.GXgXhXGX-.6.GXhXkXxXmXK 7.UXhXlXlXkX$XXXoXoXoX",
"oXoX.X:Xe.+.SXzX3Xp.<.  K.VXhXjXL 4._ NXhXhXHX-.' JXgXhXVXU N.CXjXjXBXQ 7 _. XxXlXlXkX$XXXoXoXoX",
"oXoXoXOX$Xb wXbXzXKXCX;.tXjXFXY.B qXM +XCXsXCXZ.x.ZXsXCX#Xl :XxXkXzXgXo.Q F 7.bXkXlXkX$XXXoXoXoX",
"oXoXOX{.dXu.I FXmXsXsXNXjXDXtXj T.gXS.n bXCXgXbXnXgXCXvXm M.qXkXlXlXlXSXSXFXCXkXlXlXkX$XXXoXoXoX",
"oXoXOX|.4XCX .J <XBXDXCXnX(.f n.xX=XHX8.M #XBXAXAXBX#XM q.NX=XcXzXxXzXkXjXjXkXxXzXxXzX$XXXoXoXoX",
"oXoXOX|.8XBXSXx.B } 8.5.Q F _.PXpX:XfXmXn.k ~ 0.0.~ k n.NXtX-XfXdXdXdXdXdXdXdXdXdXdXsX#XXXoXoXoX",
"oXoXXX@XT.x.n.L.z.] A G $.C.H.x.Z.$X:X%XdX8X3.z z 3.9XdX%X-X#X:X;X;X;X;X;X;X;X;X;X;X;X+XoXoXoXoX",
"oXoX|.<X|         o $ # .       7 7XzXSX`.P Y +.O.R P _.GXaX:XcXzXxXxXzXjXkXzXxXzXxXzX$XXXoXoXoX",
"oXoX X<X+.  + X .         X O   y 3XDXc.g U.VXUXUXbXP.g b.MX*XzXkXlXkXzXGXSXlXkXlXlXkX$XXXoXoXoX",
"oXoX X<XO.  o               X   w iX^.g uXSXH.y.8.+XUXrXk Y.9XkXlXkXcXfXv.A.lXzXkXlXkX$XXXoXoXoX",
"oXoX X<XO.  o               X   r qXA (.HXqX2 +.;.(.vXAX`.b 2XzXkXkXMXH Z c ;.ZXhXlXkX$XXXoXoXoX",
"oXoX X<XO.  o               X   h G.U mXlXuXs g.*XZXjXjXNXH S.VXjXzXjXT.HX^.j VXjXlXkX$XXXoXoXoX",
"oXoX X<XO.  o               X   n 3.-.DXkXaXa K q c.AXdXFX*.8.GXhXlXkXAXMXc p.SXhXlXkX$XXXoXoXoX",
"oXoX X<XO.  o               X   n <.>.GXhXhXqXUXV.D SXdXHX;.5.HXhXlXlXZX_ [ GXkXlXlXkX$XXXoXoXoX",
"oXoX X<XO.  o               X   l v.( VXkXsXY !./  .FXdXZXQ c.ZXhXjXVX%.0 -X3XlXlXlXkX$XXXoXoXoX",
"oXoX X<XO.  o               X   u <Xn <XmXvXn.l W 9XzXmX2Xj %XcXkXzXhXU B v ;.nXkXlXkX$XXXoXoXoX",
"oXoX X<XO.  O               X   w dXj.J FXnXMXmXNXlXbXDXK i.wXjXlXlXlXNXnXnXbXlXlXlXkX$XXXoXoXoX",
"oXoX X<XO.  X               .   r 5XZXX.U wXAXSXSXSXwXI +.bX-XxXlXlXlXkXkXkXlXlXlXlXlX$XXXoXoXoX",
"oXoX X,X+.  @ o o o o o o o +   u 5XxXMXr.l X.g.g.X.l r.VXsX;XzXkXkXkXkXkXkXkXkXkXlXkX$XXXoXoXoX",
"oXoXoXOX_.T.E.R.R.R.R.R.R.R.E.R.Q.+X#X#X6X).5._ _ 5._.6X#X#X@X$X$X$X$X$X$X$X$X$X$X$X$XoXXXoXoXoX",
"oXoXoXoX@X%X$X$X$X$X$X$X$X$X$X$X#XoXXXXX|.@X>X2X2X>X@X|.XXXXoXXXXXXXXXXXXXXXXXXXXXXXXXXXoXoXoXoX",
"oXoXoXoXXXXXXXXXXXXXXXXXXXXXXXXXXXoXoXoXoXXX.X X X.XXXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX"
};

/* XPM */
static const char *const xpm_icon_5[] = {
/* columns rows colors chars-per-pixel */
"44 44 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXOXOXoX.X X X.XXXOXOXOX.X X X X X X X X X X|.XXOXOXOXXX.X X X.XoXOXOXoXoXoXoXoX",
"oXoXoXoX.X X{.oX>X<X<X,X$X{.|. X-X<X,X,X,X,X,X,X,X,X<X$X|.|.{.$X,X<X<X>XoX{. XXXoXoXoXoX",
"oXoXoX.X,X8XdX<Xy.( Q ;.`.gX0X2X:.W ) / / / / / / ) R B.eX8XhX`.;.Q ( y.<XdX7X%XXXoXoXoX",
"oXoXOX X8XKXW.S ,.R.^.d.J 7.ZXsXi                     5.VXBX7.K d.~.Y.<.A Q.HX%X.XoXoXoX",
"oXoXOX{.dXW.N <XUXvXzXUXbX..*.xXx   @ o o o o o o @   9.HX$.X.bXUXBXMXKX2XN E.7X}.OXoXoX",
"oXoXoXoX<XS ,XUXS.h M I.VXSXE A.S   X             o   g.!.Y FXMX/.2 J.MXCX2XZ XXOXoXoXoX",
"oXoX.X>Xy.1.GXcXK.-Xp.( SXNX).~ S   X             o   f...(.VXzXT.v B.DXpXJX,.5.,X.XoXoX",
"oXoX X<X( U.ZXdXIX|.# _.VXlXtXW h   X             o   2.^ tXxXgXUXO.v.FXfXZXI.( <X XoXoX",
"oXoX X<XQ Q.CXjXiXSXl.' CXkXaXW d   X             o   ,.~ aXzXhXAX| n.FXfXCXQ.! <X XoXoX",
"oXoX.X,X;.f.SXNX@.3.<.! CXbX*XE M   X             o   t.` &XmXfXGX~ j.GXaXGXs.#.<X XoXoX",
"oXoXXX$X`.J bXnX1X$.%.0XjXIX<.8.H   X             o   l.h.>.UXaXMXV.].nXkXnXG I.%XXXoXoX",
"oXoXOX{.gX7...FXFXKXJXVXIXH.F yXb   @ o o o o o o @   e.vXA J.UXnXCXNXVXGX .6.9X}.oXoXoX",
"oXoXOX|.qXDX;.W (.wXiX&X<.J eXlXu                     3.HX9XJ 3.;XsXyX'.Q :.AX=X.XoXoXoX",
"oXoXoXXX;X7XtXB._ T Y ! 9.2XwX,X1.^ _ +.&.o.o.&.+.` ! C.7XwX4X-.F F F K x.iX6X#XXXoXoXoX",
"oXoXoX.X1XwXhX&X1.S m [ R.gXuX;XyXnXFX}.:.^ ^ :.}.DXnX1X7XeXrXcXaX4X8XkXkXqXeX%XXXoXoXoX",
"oXoXOX|.9XJXj.Z c.=X9XW.^ ' vX0XqXBX-.L C.>X:XZ.K ;.BX<XdXbXcXkXcXFXNXkXzXcXbX=X.XoXoXoX",
"oXoXOX{.gXv.I zXGXBX3XcXLXr.( 0XjX,.o.CXUXtXeXHXZXo.<.tXyXxXjXcXlX'.0XnXjXkXzX=X.XoXoXoX",
"oXoXoX+X@XS sXbXbX|.  ~.mXKX..f.[.L VXMX{.= 5.AXhXZXU Z.cXlXlXzXU B B <XnXjXzX=X.XoXoXoX",
"oXoX.X,X5.e.HXsXNX` * ^.BXmXXX^ #.D.AXlX;X[ 4.GXsXDXF.( MXkXxXaXG.UXY b.FXhXzX=X.XoXoXoX",
"oXoX X<X~ E.BXVXT.,.X.U.AXkXpXT V ,XmXdXUXp.;.HXfXmX;XK zXlXlXjXUX].g wXvXkXzX=X.XoXoXoX",
"oXoX X<X~ R.BXCXL J s e.ZXkXpXT V >XnXgXDXe.<.HXfXmX-XK zXlXjXmX4XM :XGXgXlXzX=X.XoXoXoX",
"oXoX.X,X6.w.GXhX{.K.0 a.CXmXXX^ #.D.DXsXJX4.@.KXaXDXF.) MXjXlXzXw M c.-XnXkXzX=X.XoXoXoX",
"oXoXoX+X#XS aXmXvXPX/.2XxXLX .f.{.L ZXkXcX.X[.vXkXZXI A.cXkXxXaXb.s.7.>XbXkXzX=X.XoXoXoX",
"oXoXOX{.gXv.P lXDXcXDXFXGXe.( 0XjX<.X.ZXAXAXSXAXZXX.<.tXyXzXkXzXDXGXJXbXjXkXzX=X.XoXoXoX",
"oXoXOX X9XJXk.D b.*X;XT._ [ bX0XrXAX,.K D.;X;XD.K <.AX2XsXbXcXcXkXkXkXxXcXcXvX=X.XoXoXoX",
"oXoXoXXX&X,XrXR.[ J G Q h.0X4X$X-X1XrXW.| V V  .W.rX<X%X>X1X1X1X1X1X1X1X1X1X1X#XXXoXoXoX",
"oXoX X>X..% 3 q s r w p u 4 $ +.sXsXgXN.] I I [ N.gXhX;XeXsXpXaXiXyXiXaXpXpXsX&X.XoXoXoX",
"oXoX X<X~                     ( MXjX^ | =XBXVX@X} / xX4XaXvXxXzXnXKXVXzXxXxXcX=X.XoXoXoX",
"oXoX X,X(   O . . . . . . +   ` ZX) t.UXOXx.j.eXUXr.] qXiXxXjXbXwXx.OXmXjXlXzX=X.XoXoXoX",
"oXoX X,X/   o             o   $.R.^ HXbXn  .y.%XcXHX_ j.bXkXlXjXC ) z oXMXjXzX=X.XoXoXoX",
"oXoX X,X/   o             o   %.#.U.CXbXV ' Q.mXgXZXR.! mXkXzXdXOXUXY B.DXhXzX=X.XoXoXoX",
"oXoX X,X/   o             o   X.^ -XbXnX3.6.n v.AXvX>XJ zXlXlXjXUXN.v hXzXkXzX=X.XoXoXoX",
"oXoX X,X/   o             o   o.) #XMXkXXXUXd.X.HXvX%XL xXlXjXBX[.M dXAXhXlXzX=X.XoXoXoX",
"oXoX X,X/   o             o   *.5.z.DXnXO.V z (.bXDXv.{ NXjXzXgX3 b =.+XmXjXzX=X.XoXoXoX",
"oXoX X,X(   o             o   X.;XV lXNXgXU.OXcXnXlXS W.lXlXzXdX].Y.S.8XvXkXzX=X.XoXoXoX",
"oXoX X,X(   O . . . . . . O   ) GXf.I aXHXUXLXFXsXP k.yXyXxXkXzXVXAXDXvXkXlXzX=X.XoXoXoX",
"oXoX X<X!                     ( xXAXc.Z 0.Y.Y.q.Z c.GX,XsXcXzXzXkXkXkXzXzXzXcX=X.XoXoXoX",
"oXoXXX@XY.M.C.V.V.V.V.V.V.C.M.T.=X%X9X(.:.~ ~ :.).9X&X#X&X=X=X=X=X=X=X=X=X=X=XOXXXoXoXoX",
"oXoXoXXX$X=X*X=X=X=X=X=X=X*X=X$X.X.X}.@X,X<X<X,X@X}..XXX.X.X.X.X.X.X.X.X.X.X.XXXoXoXoXoX",
"oXoXoXoXXX.X.X.X.X.X.X.X.X.X.XXXoXoXOXXX.X X X.XXXOXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX",
"oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX"
};

/* XPM */
static const char *const xpm_icon_6[] = {
/* columns rows colors chars-per-pixel */
"32 32 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"oXoXoXOXOXXX X XXXOXOXXX|. X X X X X X|.XXOXOXXX X X.XoXOXoXoXoX",
"oXoXXX|.|.=X>X>X=X|.}.#X,X>X>X>X>X>X>X,X@X|.}.$X>X>X;XXX}.XXoXoX",
"oXXX&X9XqXV.-.-.C.0XwXT.&.>.:.:.:.:.>.&.R.8XyX~.3.&.f.>XrX%XXXoX",
"OX|.9XlX*.r.#X.Xq.&.MXx.                h.UXf.%./.@Xx.} ;XtX{.OX",
"OX|.qX*.R.CXb.(.UXP.2.B.  @ o o o o @   G.S.4.IX:X^.UX5X] XX+XoX",
"XX=XC.0.UX~.r.T +XUXp.'   .         X   i.;.zXmX+.T mXDXQ.*.>X.X",
" X>X>.(.mXJX%XD pXVX|.M o           .   { k.CXcX,X%.NXzXrX| @XXX",
" X>X>.^.GXXX1X..!.KX{.M O           .   { k.VXbX$X} BXlXrX| @XXX",
"XX=XC.9.UX).W #.7XPXi.]   .         X   p.;.zXMX-X6.xXFXW.*.>X.X",
"OX|.wX-.U.UXMXVXUXP.4.B.  o         o   F.F.6.GXSXCXJX7X[ oX+XoX",
"OX|.6XsXO.w.XX.Xw.o.xXv.    . * = +     k.HXi.O.P.).k.` %XeX}.OX",
"oXXX%X0XhXq.j g q.hX0X}.R.|.M.O.} p.[.!.|.5XuX^.w.5.l.>XtX%XXXoX",
"OX|.5XnX9.4.Y./.4.0.lX8XJXM.=.L.E.8.6.vXwXhXkXMXUXUXAXxXxX4X XOX",
"OX}.tX8.x.FXcX@XSXc.<.zXf.6.DX7X2XLXL.+.8XjXkXcX_.K.lXkXcX3X XOX",
"XX&XL.1.FXSX9.6 zXKX1.z.;.VXlXG $.CXKXi.k.VXcX4X$.| m.AXlX3X XOX",
" X>X1.Q.FX8XX. .fXVX{.v K.VXnXQ.5.AXbX#X=.CXjXdXUX4.V.AXlX3X XOX",
" X>X;./.UXg.A C 5XZXOXf T.NXVXQ.,.DXcX-X*.VXgXZXc.4.FXhXcX3X XOX",
".X-Xc.s.PX5X~.T 0XIXh.-.r.SXnX^.8.MXFXS.q.CXcX5Xi +. XmXzX3X XOX",
"oX X5X...XUXDXzXLXXX' uX:.U.UXcXhXJX8X' &XzXzXgXwX;XtXzXcX3X XOX",
"OX}.rXaX@.V.,X3XV.#.rXyXsXO.p.1X9XH.) $XtXgXzXxXbXMXvXkXvX4X XOX",
"oX+X_.(.R.} H H } R.(.XX8XdXd.M z &.7XtX%X4X5X4X2X2X4X4X6X=XXXoX",
" X,X-.    * % % *     R.HXG.:.m.Z.4.u.lX5XfXkXhXvXMXhXhXzX3X XOX",
" X>X:.  o         .   }.T.%.tX*X.XkXx.3.rXhXlXnX1XOXmXkXvX4X XOX",
" X>X:.  o       .     D.@.AX_.N z.0XUX5.N.NXcX7X[ / K.CXzX3X XOX",
" X>X:.  o           & %.m.UXW.z i.yXVXXX-.CXkXuXFXr.h.FXlX3X XOX",
" X>X:.  o           = } L.FX,X5X1.v.IX=X*.BXfXAX!.=.CXjXcX3X XOX",
" X>X:.  o           @ 0.y.IX$Xo./ }.UXI.5.ZXxX9Xq *.&XbXxX3X XOX",
" X>X>.  @ o o o o O   _.-.}.UX*X:XLXgX] |.cXzXpX@X(.4XxXxX3X XOX",
"|.,X%.                /.sX[ D.aXgX].| ).iXjXcXbXZXDXMXxXmX5X XOX",
"XX%XA.%.>.:.:.:.:.:.-._.tX-X1.{ } @./.yX%X3X4X3X2X1X3X3X5X*X.XoX",
"oXXX%X,X>X>X>X>X>X>X,X+X{.oX>X#X+X:X#X{.XX X X X X X X X X.XoXoX",
"oXoXXX|. X X X X X X XoXOXoX.XXXoX.XXXOXoXOXOXOXOXOXOXOXOXoXoXoX"
};

/* XPM */
static const char *const xpm_icon_7[] = {
/* columns rows colors chars-per-pixel */
"24 24 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"OX X.X:X+X$X-X}.#X,X>X>X>X>X,X$X{.&X*XOX;X+X|.OX",
" X6XqXh.w.7.A.lXn.A U P P U A b.cX~.8.9.r.;X0X|.",
".XqXe.~.%X8Xb.J.t.            u.oXe.4X7X$X7.$X@X",
":Xg._.jX$.w.UXn.^   + o o @   ,.i.DXI...UX1X1.&X",
"@X5.iXZX.X*.SX>Xx   .     .   P Q.SX2X7.xXMXr.^.",
"%X4.fX,Xs.#.MX&Xv   .     X   W P.GX4X>.cXMX8._.",
"-XD.M.ZXK.3XBXa.+.  X     X   0.p.wXCX:XUX_.r.-X",
"|.iXz.c.eX:X6.}.p.  + % % $   t.0X;.E.=XM.w.7XXX",
".X1XxXt.n S P.vX].{.n. .{ p.].|.pX,XM.j.H.tX4X X",
"|.aXv.b.8X>Xt.Y.MX'.p.>X,Xb.D.dXfXnXGXAXFXcXwX X",
"-XA.v.UXD.g.IX9.H.w.GXj.F.UXk.C.MXvXx.+.;XNXqX X",
"%X4.iXkX^ 6.IX@XD *XHXV.f.HX9X9.mXfXlXe.~.DX0X X",
"@X2.cX}.A +.DX-XB ,XGX_.d.FXeX0.cXBXF.:.nXxXwX X",
":Xh.R.UX=XU.UXg.i.v.UX>X).UXI.j.NXvXp.9.5XMXqX X",
".XuXf.(.cXxXB.C.cXx.c.kXmXT.q.0XlXzXAXVXxXvXeX X",
"oX{.Q.O.~ Q 4.'.#XkXC.P H t.aX1X7X0X5X4X8XqX1X.X",
",XH   * X + $   '.2Xr.E.R.i.^.iXsXhXMXVXlXlXqX X",
">XI   .         L.t.3Xn.E.cXe.^.bXmXP.y.yXmXwX X",
">XP   o   .   % #.XXgXc M.CX2X9.NXgX>X<.U.FX0X X",
">XP   o       % ] 3XsX~.$.>XhX0.xXnX:X0.kXvXwX X",
">XU   @ o o X & 3.I.GXu.5.CXoXr.MXmX&.@.9XnXqX X",
",XS             (.g.'.mXVX4X5.-XbXxXvXfXjXmXrX X",
"*X2.S U P P I H {.rX0.8.e.2.%X8X9XeXwXrXeXrX2X.X",
"XX*X,X>X>X>X>X,XoXXX-X_.^.*X@X|..X X X X X X.XoX"
};

/* XPM */
static const char *const xpm_icon_8[] = {
/* columns rows colors chars-per-pixel */
"16 16 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"XXOX$X].#X@X-X-X-X-XOX$X].@X+XXX",
"OX1XF.S.I.`.B V V M |.E.D.A.*X+X",
"#XJ.@XZ.;X9.        y.=XU.6XC.oX",
"].Z.NX1.uXt.  @ O @ 1.HXl.cXY.Q.",
"#XG.#XoX4X5.        e.>X7X5XV.oX",
"XX8Xb.t.B.@X[ Z M ` #XR.R.F.=X+X",
"#X.XE.Q.H.%X.X/..X^.yXcX+XzXiX X",
".XC.iX-.aX0.}.].[.=X/.BXk.%XfX|.",
"}.Z.8X-.dX7.XX0X$X1X/.cX0.tXpX X",
"$X.X XsX`. XT.OX-XF.7XgX>XfXrX.X",
"#Xe.m d v V.<X7.,.].pXuXxXgX6XXX",
";Xk       J ].C.#XY.;XcXF.9XsX|.",
"-XS   $   z qXm.n.qXE.VXs.:XsX|.",
";Xx       C .X&XoX_.+XlXx.gXpX X",
"&XO.x S k r.|.A.I.I.wXyXfXuX6X.X",
"XX&X;X-X;X$X$X_./.%X.X X|. X.XoX"
};

const char *const *const xpm_icons[] = {
    xpm_icon_0,
    xpm_icon_1,
    xpm_icon_2,
    xpm_icon_3,
    xpm_icon_4,
    xpm_icon_5,
    xpm_icon_6,
    xpm_icon_7,
    xpm_icon_8,
};
const int n_xpm_icons = 9;
